/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_I6wprYIi);
  numBytes += sLine_init(&sLine_vTfbv1xq);
  numBytes += sLine_init(&sLine_cvU3u3b4);
  numBytes += sLine_init(&sLine_knz5PubY);
  numBytes += sLine_init(&sLine_jFr06Sw1);
  numBytes += sBiquad_init(&sBiquad_s_XHsLvNKH);
  numBytes += sLine_init(&sLine_Qs1dRYiM);
  numBytes += sLine_init(&sLine_kDXkBOSj);
  numBytes += sLine_init(&sLine_ilkqabTU);
  numBytes += sLine_init(&sLine_mr2uuxAO);
  numBytes += sBiquad_init(&sBiquad_s_IX4R3335);
  numBytes += sLine_init(&sLine_wK6nvYIF);
  numBytes += sLine_init(&sLine_z0kfwbHu);
  numBytes += sLine_init(&sLine_FL2esOLa);
  numBytes += sLine_init(&sLine_70Lbg4tp);
  numBytes += sLine_init(&sLine_bym6TQ35);
  numBytes += sBiquad_init(&sBiquad_s_xGA0I8MV);
  numBytes += sLine_init(&sLine_NcFBbVig);
  numBytes += sLine_init(&sLine_XzNvP8n7);
  numBytes += sLine_init(&sLine_ZepcElHM);
  numBytes += sLine_init(&sLine_f0o5g4BF);
  numBytes += sLine_init(&sLine_97GiIisa);
  numBytes += sBiquad_init(&sBiquad_s_4EMx2Esp);
  numBytes += sLine_init(&sLine_kCNhuBUy);
  numBytes += sLine_init(&sLine_tCDmgDXu);
  numBytes += sLine_init(&sLine_PITmoIZn);
  numBytes += sLine_init(&sLine_WXVJivOp);
  numBytes += sBiquad_init(&sBiquad_s_izkiXmgm);
  numBytes += sLine_init(&sLine_xNt8xlfB);
  numBytes += sLine_init(&sLine_VMq9IJQU);
  numBytes += sLine_init(&sLine_Ce9s4Hqw);
  numBytes += sLine_init(&sLine_VM32LE3s);
  numBytes += sLine_init(&sLine_1dn2ZUdU);
  numBytes += sBiquad_init(&sBiquad_s_p7aR0ZxA);
  numBytes += sLine_init(&sLine_gX3smx94);
  numBytes += sTabread_init(&sTabread_88P4l8N4, &hTable_Nqxc8Gqx, true);
  numBytes += sLine_init(&sLine_EKWHcDK0);
  numBytes += sLine_init(&sLine_WUhCUCVK);
  numBytes += sTabread_init(&sTabread_9fuDOVFz, &hTable_VFBC1AYT, true);
  numBytes += sLine_init(&sLine_WBSmVDMx);
  numBytes += sRPole_init(&sRPole_kgq26g21);
  numBytes += sDel1_init(&sDel1_X2Sw2L0r);
  numBytes += sTabwrite_init(&sTabwrite_IZSaLWyz, &hTable_Nqxc8Gqx);
  numBytes += sRPole_init(&sRPole_gjXGKYVF);
  numBytes += sDel1_init(&sDel1_PuDzHXUA);
  numBytes += sTabwrite_init(&sTabwrite_DAZh7ws1, &hTable_VFBC1AYT);
  numBytes += sLine_init(&sLine_EnmN5MUc);
  numBytes += sLine_init(&sLine_0tHkpsEL);
  numBytes += sRPole_init(&sRPole_YqVFHmBt);
  numBytes += sEnv_init(&sEnv_1Xc2WVmh, 1024, 512);
  numBytes += sRPole_init(&sRPole_zZbGySmU);
  numBytes += sLine_init(&sLine_latT5FNF);
  numBytes += sLine_init(&sLine_g7HO80IZ);
  numBytes += sRPole_init(&sRPole_dCTlh1WD);
  numBytes += sEnv_init(&sEnv_4Y8LDrh0, 1024, 512);
  numBytes += sRPole_init(&sRPole_NfBItrPI);
  numBytes += sLine_init(&sLine_DBGJo0M6);
  numBytes += sTabread_init(&sTabread_tEe7T59t, &hTable_bkrY9PzY, true);
  numBytes += sLine_init(&sLine_qXFagoE8);
  numBytes += sLine_init(&sLine_szICNOzI);
  numBytes += sTabread_init(&sTabread_JBbdrubd, &hTable_CLjbKCjX, true);
  numBytes += sLine_init(&sLine_yS8mLSqf);
  numBytes += sRPole_init(&sRPole_rG9IBoGB);
  numBytes += sDel1_init(&sDel1_MMRDclYn);
  numBytes += sTabwrite_init(&sTabwrite_YNhQVaMz, &hTable_bkrY9PzY);
  numBytes += sRPole_init(&sRPole_spxhUw54);
  numBytes += sDel1_init(&sDel1_8c53qvK0);
  numBytes += sTabwrite_init(&sTabwrite_U0lQgC0L, &hTable_CLjbKCjX);
  numBytes += sLine_init(&sLine_RTCmVshi);
  numBytes += sLine_init(&sLine_7YEMQ66A);
  numBytes += sRPole_init(&sRPole_MR9TixRZ);
  numBytes += sEnv_init(&sEnv_FmRRQinS, 1024, 512);
  numBytes += sRPole_init(&sRPole_Zh59bdsm);
  numBytes += sLine_init(&sLine_IlN73JKL);
  numBytes += sLine_init(&sLine_CHRiuvds);
  numBytes += sRPole_init(&sRPole_rP88tipV);
  numBytes += sEnv_init(&sEnv_VMyB4ERs, 1024, 512);
  numBytes += sRPole_init(&sRPole_SHyL1paq);
  numBytes += sLine_init(&sLine_HJqrgxnp);
  numBytes += sTabread_init(&sTabread_EQCjqBiZ, &hTable_Km1SNKyV, true);
  numBytes += sLine_init(&sLine_VakqqU9H);
  numBytes += sLine_init(&sLine_svvfxEeX);
  numBytes += sTabread_init(&sTabread_Ghk2qPiE, &hTable_rzixzLEt, true);
  numBytes += sLine_init(&sLine_OHFFT9xn);
  numBytes += sRPole_init(&sRPole_Neh5Qp7D);
  numBytes += sDel1_init(&sDel1_lYbUgBbd);
  numBytes += sTabwrite_init(&sTabwrite_d5YAn1r5, &hTable_Km1SNKyV);
  numBytes += sRPole_init(&sRPole_rY6vTiS5);
  numBytes += sDel1_init(&sDel1_p5czLoNC);
  numBytes += sTabwrite_init(&sTabwrite_InYlpA9W, &hTable_rzixzLEt);
  numBytes += sLine_init(&sLine_QDv9EnMu);
  numBytes += sLine_init(&sLine_7hOZIiUh);
  numBytes += sRPole_init(&sRPole_PK2pWXDD);
  numBytes += sEnv_init(&sEnv_cdB17ugT, 1024, 512);
  numBytes += sRPole_init(&sRPole_spYDqcfF);
  numBytes += sLine_init(&sLine_DQcT6Jcw);
  numBytes += sLine_init(&sLine_rVxW7bIZ);
  numBytes += sRPole_init(&sRPole_Gm1ycBpY);
  numBytes += sEnv_init(&sEnv_GweqS9hl, 1024, 512);
  numBytes += sRPole_init(&sRPole_tdCrF4Zt);
  numBytes += cVar_init_f(&cVar_NM6acaFf, 0.0f);
  numBytes += cVar_init_f(&cVar_2f0nSEdB, 0.0f);
  numBytes += cVar_init_f(&cVar_LvVjHrVH, 0.0f);
  numBytes += cVar_init_f(&cVar_KQMSurnD, 0.0f);
  numBytes += cSlice_init(&cSlice_X5QTJyHK, 1, -1);
  numBytes += cVar_init_f(&cVar_vRh2iLfO, 1337.0f);
  numBytes += cVar_init_f(&cVar_slhxln3W, 0.0f);
  numBytes += cIf_init(&cIf_tn2lfbsG, false);
  numBytes += cIf_init(&cIf_3GoU4Nr5, false);
  numBytes += cBinop_init(&cBinop_t0V6F5vQ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ZrQVmGUI, false);
  numBytes += cBinop_init(&cBinop_VS5rYEs7, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_swXUVnjK, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_AOYXGAiQ, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_LDRqaBeT, 0.0f);
  numBytes += cIf_init(&cIf_24V0HBxx, false);
  numBytes += cIf_init(&cIf_KTk1ffSM, false);
  numBytes += cBinop_init(&cBinop_TGvFAfzA, 0.0f); // __pow
  numBytes += cIf_init(&cIf_DxavvTPC, false);
  numBytes += cBinop_init(&cBinop_1sGYrgpb, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_VglbAqvK, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_FsJEsu0F, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_tSpa8K8l, 0.0f);
  numBytes += cIf_init(&cIf_aIreGWdO, false);
  numBytes += cIf_init(&cIf_sNTOeslz, false);
  numBytes += cBinop_init(&cBinop_sB2VMDM5, 0.0f); // __pow
  numBytes += cIf_init(&cIf_DMXDfLOV, false);
  numBytes += cBinop_init(&cBinop_nAUf44ZC, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_b7bYCJYZ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_UJcNyWNj, -15.0f); // __eq
  numBytes += cIf_init(&cIf_j5JMxdDP, false);
  numBytes += cSlice_init(&cSlice_Yl6L9LUA, 1, -1);
  numBytes += cVar_init_f(&cVar_eUHb5rIu, 0.0f);
  numBytes += cSlice_init(&cSlice_iOK9D8PJ, 1, -1);
  numBytes += cVar_init_f(&cVar_0mwQgrcS, 0.0f);
  numBytes += cSlice_init(&cSlice_dqLFwkio, 1, -1);
  numBytes += cVar_init_f(&cVar_LrfnwP1u, 0.0f);
  numBytes += cSlice_init(&cSlice_hufttvo2, 1, -1);
  numBytes += cVar_init_f(&cVar_yLKjRODC, 0.313f);
  numBytes += cBinop_init(&cBinop_hQr4HLOQ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_zDVHL04v, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_avZxaQtb, 0.0f);
  numBytes += cVar_init_f(&cVar_YVlpIwUP, 1337.0f);
  numBytes += cVar_init_f(&cVar_KQu9AF0Q, 0.3f);
  numBytes += cBinop_init(&cBinop_raLUnb9g, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ru8pw08y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RdvjW3Sm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TPADUDmB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AkOY2QXc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dBVb3KwG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YvRM2XRe, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_1Bw5EsH2, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_IHb0aMKh, 0.0f);
  numBytes += cVar_init_f(&cVar_BX1c18fq, 1337.0f);
  numBytes += cVar_init_f(&cVar_cU3R3pdQ, 0.313f);
  numBytes += cBinop_init(&cBinop_Z5IWpqhm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KstAfwlN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_575DFFeU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_F8XoCP6o, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dsuPEG4O, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Z1GnK64j, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_sxtQxfNx, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_alngRCJ4, 0.0f);
  numBytes += cVar_init_f(&cVar_DjLqCqSv, 1037.0f);
  numBytes += cVar_init_f(&cVar_NgBm4msn, 0.4f);
  numBytes += cBinop_init(&cBinop_IMV961Iv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oYjT3kGw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_buzQcm7E, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5AIB8g0d, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SEvr1nwH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_paej8YCT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VjwpR1c3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_W86PE782, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Wn8wvYRI, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_MfR8pJ76, 1, -1);
  numBytes += cVar_init_f(&cVar_mvNnx7Xc, 1337.0f);
  numBytes += cVar_init_f(&cVar_12UxQ21Y, 0.0f);
  numBytes += cIf_init(&cIf_lB3Uv6II, false);
  numBytes += cIf_init(&cIf_R34oKHNn, false);
  numBytes += cBinop_init(&cBinop_g3n2B0az, 0.0f); // __pow
  numBytes += cIf_init(&cIf_TuwKMYrC, false);
  numBytes += cBinop_init(&cBinop_mb3oE3v8, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_hhL3pet9, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_8z84LUyh, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_7E1XdGHn, 0.0f);
  numBytes += cIf_init(&cIf_Ygyl14yl, false);
  numBytes += cIf_init(&cIf_VOnX6RRg, false);
  numBytes += cBinop_init(&cBinop_LvBViZdD, 0.0f); // __pow
  numBytes += cIf_init(&cIf_7CBWkL4a, false);
  numBytes += cBinop_init(&cBinop_w1R9K5iH, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_b3sXKXwx, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_cvTLQTCc, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_cIQFoNpQ, 0.0f);
  numBytes += cIf_init(&cIf_qTpIXfd7, false);
  numBytes += cIf_init(&cIf_fYVDozGx, false);
  numBytes += cBinop_init(&cBinop_qEvvKoDX, 0.0f); // __pow
  numBytes += cIf_init(&cIf_xmQJHb4B, false);
  numBytes += cBinop_init(&cBinop_9JaygyU2, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_aw093SGk, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_yTBUc0nx, -15.0f); // __eq
  numBytes += cIf_init(&cIf_TzScbUvH, false);
  numBytes += cSlice_init(&cSlice_5uQrIjET, 1, -1);
  numBytes += cVar_init_f(&cVar_v9zvijTR, 0.0f);
  numBytes += cSlice_init(&cSlice_NbSvJyFh, 1, -1);
  numBytes += cVar_init_f(&cVar_THS3pkUe, 0.0f);
  numBytes += cSlice_init(&cSlice_MqJLvnl2, 1, -1);
  numBytes += cVar_init_f(&cVar_ZaHymWZE, 0.0f);
  numBytes += cSlice_init(&cSlice_CXNbEvTW, 1, -1);
  numBytes += cVar_init_f(&cVar_eVnSRCCV, 0.313f);
  numBytes += cBinop_init(&cBinop_EPG709YP, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_lIPXNBdJ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_2PomZlgo, 0.0f);
  numBytes += cVar_init_f(&cVar_0AjaKOCA, 1337.0f);
  numBytes += cVar_init_f(&cVar_bvpXtVjF, 0.3f);
  numBytes += cBinop_init(&cBinop_cKOwQ6aT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2sOgt4Br, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uiZKOsFk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vxPCdxuw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bBqQdf7z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_srsnJC2J, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WWtFhVF3, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_SjxKMMGK, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_VUx2jcoR, 0.0f);
  numBytes += cVar_init_f(&cVar_K8H53V02, 1337.0f);
  numBytes += cVar_init_f(&cVar_mcKjSTdE, 0.313f);
  numBytes += cBinop_init(&cBinop_FYBJy8bb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Jw7ZXvnP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xAof12Md, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xNQKtOXH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_a765pIG5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_a1PtdLvk, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_weLJ8C3U, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_dYtbj4qs, 0.0f);
  numBytes += cVar_init_f(&cVar_zJKK0H0m, 1037.0f);
  numBytes += cVar_init_f(&cVar_fpVPVmtH, 0.4f);
  numBytes += cBinop_init(&cBinop_xeUL34IS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sLR1EyYJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wx1eI35P, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jlsRPgA7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bcW2LJT7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cmho8iaF, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_cGjQBxew, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Z4Zl93tK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WYEtuFBT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_biqfvRpA, 5705.6f);
  numBytes += cVar_init_f(&cVar_olQdH4g6, 313.3f);
  numBytes += cBinop_init(&cBinop_30IyXZjo, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_pcr5SIS8, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_MzQo6Uj5, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_qAVGWcS9, 0.0f);
  numBytes += cVar_init_f(&cVar_ztHRwYth, 0.0f);
  numBytes += cVar_init_f(&cVar_RB9gw8rI, 0.0f);
  numBytes += cVar_init_f(&cVar_IulijYFc, 0.0f);
  numBytes += cVar_init_f(&cVar_8K1lHMHg, 0.0f);
  numBytes += cVar_init_f(&cVar_Rn46oavl, 0.0f);
  numBytes += cVar_init_f(&cVar_Y3rqq0F1, 0.0f);
  numBytes += cVar_init_f(&cVar_SKw5e4jd, 0.0f);
  numBytes += cVar_init_f(&cVar_gDNdjVse, 0.0f);
  numBytes += cVar_init_f(&cVar_VHZl2OXc, 0.0f);
  numBytes += cVar_init_f(&cVar_WrYkEG8W, 0.0f);
  numBytes += cVar_init_f(&cVar_5wvHkT4E, 0.0f);
  numBytes += cSlice_init(&cSlice_V8vrSoO5, 1, -1);
  numBytes += cVar_init_f(&cVar_Z3d5nhTW, 0.5f);
  numBytes += cSlice_init(&cSlice_r6tsXFt4, 1, -1);
  numBytes += cVar_init_f(&cVar_dRzA5jTe, 0.2f);
  numBytes += cSlice_init(&cSlice_YYO4T54u, 1, -1);
  numBytes += cVar_init_f(&cVar_estm9ecK, 500.0f);
  numBytes += sVarf_init(&sVarf_yrkQtW8f, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ZPQnXi2q, 600.0f);
  numBytes += cBinop_init(&cBinop_eAN1H865, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_nCNM4r3j, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pjTm3lfw, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_DvmCnoCL, 600.0f);
  numBytes += cBinop_init(&cBinop_2SvpYIbY, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_p65BqMTm, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_T9RFLJyq, 4000.0f);
  numBytes += cBinop_init(&cBinop_WPA4W2Yi, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Ki4OCpCU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_k1LGLNE6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_WOkEE4zE, 4000.0f);
  numBytes += cBinop_init(&cBinop_VpANjil6, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_FYTaIjq2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3W3OCKMW, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_zOMGinkr, false);
  numBytes += cBinop_init(&cBinop_LMbKSIjT, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_SxEoi12Z, 20.0f);
  numBytes += cBinop_init(&cBinop_U8fP6Ga4, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_HivQpNbB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fe7Aq868, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Q490Pevp, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_2CJNcazt, false);
  numBytes += cBinop_init(&cBinop_q3AacW9T, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_11KsIFvJ, 20.0f);
  numBytes += cBinop_init(&cBinop_WqaAgiRq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_9LIrRBnH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YmmNyNCI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3cyfyuTo, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_lcYNPn7i, 1, -1);
  numBytes += cVar_init_f(&cVar_QQIHBXKs, 0.25f);
  numBytes += cDelay_init(this, &cDelay_Wb5yHw4m, 0.0f);
  numBytes += cDelay_init(this, &cDelay_E0FmBgyQ, 0.0f);
  numBytes += hTable_init(&hTable_Nqxc8Gqx, 256);
  numBytes += cTabhead_init(&cTabhead_OILW3jfW, &hTable_Nqxc8Gqx);
  numBytes += cVar_init_s(&cVar_WOcUptEj, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_9Fwkykqz, 0.0f);
  numBytes += cDelay_init(this, &cDelay_2BYFmaod, 0.0f);
  numBytes += cBinop_init(&cBinop_C0mt2yMt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RKWFvCwn, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_qejQTxiZ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Z2JCPyD1, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_JlsK62wP, 0.0f);
  numBytes += cDelay_init(this, &cDelay_mWrsbVV9, 0.0f);
  numBytes += hTable_init(&hTable_VFBC1AYT, 256);
  numBytes += cTabhead_init(&cTabhead_4As2gGAg, &hTable_VFBC1AYT);
  numBytes += cVar_init_s(&cVar_3pRlu4QV, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_Aa6T5DF4, 0.0f);
  numBytes += cDelay_init(this, &cDelay_CjkPy318, 0.0f);
  numBytes += cBinop_init(&cBinop_vZ3VPjsv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AIFV1eNy, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_OAkCJXrW, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_GQ4OscfF, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_SS7bFKBN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oiDIp1dP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_38XIk66m, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xUgvKULK, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_Lpj3vcBN, 1, -1);
  numBytes += cVar_init_f(&cVar_hK4UzVdW, 0.5f);
  numBytes += cSlice_init(&cSlice_S1kxZwp3, 1, -1);
  numBytes += cVar_init_f(&cVar_iELx3gHM, 0.2f);
  numBytes += cSlice_init(&cSlice_FKkcsOsr, 1, -1);
  numBytes += cVar_init_f(&cVar_zIxzuxHs, 500.0f);
  numBytes += sVarf_init(&sVarf_1hgTVPUz, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_VzagbFsl, 600.0f);
  numBytes += cBinop_init(&cBinop_AFq1wGAE, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_1NBiUugJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_stJtppda, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_rQr2U2ia, 600.0f);
  numBytes += cBinop_init(&cBinop_5vE3q61u, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Fl03eEjh, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_RIAQtnQo, 4000.0f);
  numBytes += cBinop_init(&cBinop_PQC7C6M4, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_0WVJXuXU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AooqllU8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_SxTaV1ZB, 4000.0f);
  numBytes += cBinop_init(&cBinop_re19H5Gg, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_w6VxHtNH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WkugDomD, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_4hMAEae9, false);
  numBytes += cBinop_init(&cBinop_1kCoJYv4, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_H6rbuXRN, 20.0f);
  numBytes += cBinop_init(&cBinop_VxMnWvs5, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_7QwyWToa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kJes2FXU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CBudM7Zj, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_DqhRPJXm, false);
  numBytes += cBinop_init(&cBinop_uJWGEZA7, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_1Qw0GnSd, 20.0f);
  numBytes += cBinop_init(&cBinop_OdguaKst, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_MC4i5IEe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AQPWyglo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mtXgrCU9, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_WVxxR57k, 1, -1);
  numBytes += cVar_init_f(&cVar_PJHOhvaL, 0.25f);
  numBytes += cDelay_init(this, &cDelay_2fJfaeeJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_jJ9GwMTL, 0.0f);
  numBytes += hTable_init(&hTable_bkrY9PzY, 256);
  numBytes += cTabhead_init(&cTabhead_CWfluwZY, &hTable_bkrY9PzY);
  numBytes += cVar_init_s(&cVar_9SK4VCUg, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_e1iilHtj, 0.0f);
  numBytes += cDelay_init(this, &cDelay_QzYdKHmI, 0.0f);
  numBytes += cBinop_init(&cBinop_Z0MjBnfJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2vGwMD56, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_WuZLbOgQ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_UlUXnhSh, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_IFYHyEpo, 0.0f);
  numBytes += cDelay_init(this, &cDelay_y7W4yyBX, 0.0f);
  numBytes += hTable_init(&hTable_CLjbKCjX, 256);
  numBytes += cTabhead_init(&cTabhead_EAFgGpid, &hTable_CLjbKCjX);
  numBytes += cVar_init_s(&cVar_NN8KfqgD, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_4l7pN7hw, 0.0f);
  numBytes += cDelay_init(this, &cDelay_8VdUPWF4, 0.0f);
  numBytes += cBinop_init(&cBinop_e5Ry4GUx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PL8PaLVY, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_4b41nFF3, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_rxTLSSJG, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_lf8XHyBb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VmRBCBy3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4NqJNcVL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zmPdkgOB, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_EP5LahlA, 1, -1);
  numBytes += cVar_init_f(&cVar_NEyD8hyQ, 0.5f);
  numBytes += cSlice_init(&cSlice_z5igXM8L, 1, -1);
  numBytes += cVar_init_f(&cVar_mSPmdp2N, 0.2f);
  numBytes += cSlice_init(&cSlice_Ns0TI7KA, 1, -1);
  numBytes += cVar_init_f(&cVar_RhIqKyIb, 500.0f);
  numBytes += sVarf_init(&sVarf_GRHbp2Gr, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_RHtcTtEW, 600.0f);
  numBytes += cBinop_init(&cBinop_rRWD1HPq, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_qiCoBg3U, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_h9QdCowF, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_5ExCfMeW, 600.0f);
  numBytes += cBinop_init(&cBinop_GUbdfTCh, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_mPM7CMKo, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_nmZyejLc, 4000.0f);
  numBytes += cBinop_init(&cBinop_KJ2vG8uL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_J6FEfXyu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fkS7dNPe, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_zRZl5bw5, 4000.0f);
  numBytes += cBinop_init(&cBinop_mnLW18g3, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_K1RdOUoV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l6KOArSv, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_WuPSM8Eg, false);
  numBytes += cBinop_init(&cBinop_ulRS0lAm, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_3SpvmZij, 20.0f);
  numBytes += cBinop_init(&cBinop_yNOqKmtR, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Cyp4TkbL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2RLt09RX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8rmWgXZf, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_tMwBAxf5, false);
  numBytes += cBinop_init(&cBinop_Li7K8xdr, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_Tnlhgbz5, 20.0f);
  numBytes += cBinop_init(&cBinop_1rgTcZcH, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Kas2Ya6A, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LeXb1Czs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cHxVmFla, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_mZPumJNZ, 1, -1);
  numBytes += cVar_init_f(&cVar_GxC6LnUz, 0.25f);
  numBytes += cDelay_init(this, &cDelay_Uh9qACET, 0.0f);
  numBytes += cDelay_init(this, &cDelay_jZBp2FRE, 0.0f);
  numBytes += hTable_init(&hTable_Km1SNKyV, 256);
  numBytes += cTabhead_init(&cTabhead_rtNHs1pf, &hTable_Km1SNKyV);
  numBytes += cVar_init_s(&cVar_uxtrqjdW, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_BX0lrHSf, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BDSPCWvr, 0.0f);
  numBytes += cBinop_init(&cBinop_q43KK0WV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YbOJSzPT, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_uArtq3hF, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_yf1i14Ax, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_dEsIw7WI, 0.0f);
  numBytes += cDelay_init(this, &cDelay_tBmGRjcA, 0.0f);
  numBytes += hTable_init(&hTable_rzixzLEt, 256);
  numBytes += cTabhead_init(&cTabhead_TUqyUSSA, &hTable_rzixzLEt);
  numBytes += cVar_init_s(&cVar_9MtLESzg, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_AagDrF5v, 0.0f);
  numBytes += cDelay_init(this, &cDelay_qwKxzDUW, 0.0f);
  numBytes += cBinop_init(&cBinop_bdnvktuQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zl4Cr4dK, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9WLhGPIT, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_CqNcb01J, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_gdWvqXbP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JNMVufC4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4OO5HHqn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WVjtE2Yy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_fEstoHfQ, 1.0f);
  numBytes += cIf_init(&cIf_IKLX05Wa, false);
  numBytes += cIf_init(&cIf_YN12LwFz, false);
  numBytes += cVar_init_f(&cVar_r3bNIcAA, 0.0f);
  numBytes += cVar_init_f(&cVar_FsKHr6XP, 0.0f);
  numBytes += cVar_init_f(&cVar_T4Glud5H, 1.0f);
  numBytes += cIf_init(&cIf_7Ajh2rFS, false);
  numBytes += cIf_init(&cIf_0Nq3IXtG, false);
  numBytes += cVar_init_f(&cVar_7zAC2a44, 0.0f);
  numBytes += cVar_init_f(&cVar_Da9sCEk9, 0.0f);
  numBytes += cVar_init_f(&cVar_oevGClSi, 1.0f);
  numBytes += cIf_init(&cIf_RYtzLkZK, false);
  numBytes += cIf_init(&cIf_aHVNALKW, false);
  numBytes += cVar_init_f(&cVar_WA0SEQCY, 0.0f);
  numBytes += cVar_init_f(&cVar_y4xo67uc, 0.0f);
  numBytes += cVar_init_f(&cVar_mkCKsYfv, 60000.0f);
  numBytes += cVar_init_f(&cVar_i5aewoiA, 500.0f);
  numBytes += cSlice_init(&cSlice_y36Bv1tR, 1, -1);
  numBytes += cSlice_init(&cSlice_bwmyZBVS, 1, -1);
  numBytes += cVar_init_f(&cVar_CLhkITmU, 0.0f);
  numBytes += cIf_init(&cIf_SUvr1fTn, false);
  numBytes += cBinop_init(&cBinop_K0gKBbV7, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_yE5SP7md, 120.0f);
  numBytes += cBinop_init(&cBinop_flfVqE0d, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_zEHuWYNw, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_5UsQDU2l, 60000.0f);
  numBytes += cVar_init_f(&cVar_gDxilEMV, 500.0f);
  numBytes += cSlice_init(&cSlice_DuH0tqqT, 1, -1);
  numBytes += cSlice_init(&cSlice_4VMUGv4y, 1, -1);
  numBytes += cVar_init_f(&cVar_Yeg8bUCn, 0.0f);
  numBytes += cIf_init(&cIf_1575Y6FW, false);
  numBytes += cBinop_init(&cBinop_w0YnjoKm, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_LsaReSyE, 120.0f);
  numBytes += cBinop_init(&cBinop_fOiKQBmP, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_ki804htm, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_PbMtZuf5, 60000.0f);
  numBytes += cVar_init_f(&cVar_xgOXansH, 500.0f);
  numBytes += cSlice_init(&cSlice_ekHP5aXT, 1, -1);
  numBytes += cSlice_init(&cSlice_tY6C54NB, 1, -1);
  numBytes += cVar_init_f(&cVar_uCU4iqGM, 0.0f);
  numBytes += cIf_init(&cIf_ifMU2Ddl, false);
  numBytes += cBinop_init(&cBinop_LeXjQPKC, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_CHUeejTP, 120.0f);
  numBytes += cBinop_init(&cBinop_RHbcIIhL, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_PrYXRgTN, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_rt1XWyxI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_o7PH2VIN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_25Hbiy0A, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gYN3tyfm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oGTRQl4N, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Wioaxwub, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LZ5U4gqK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jemOpD3E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bxX0nwSp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YQQycb0E, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_1Xc2WVmh);
  sEnv_free(&sEnv_4Y8LDrh0);
  sEnv_free(&sEnv_FmRRQinS);
  sEnv_free(&sEnv_VMyB4ERs);
  sEnv_free(&sEnv_cdB17ugT);
  sEnv_free(&sEnv_GweqS9hl);
  hTable_free(&hTable_Nqxc8Gqx);
  hTable_free(&hTable_VFBC1AYT);
  hTable_free(&hTable_bkrY9PzY);
  hTable_free(&hTable_CLjbKCjX);
  hTable_free(&hTable_Km1SNKyV);
  hTable_free(&hTable_rzixzLEt);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_Nqxc8Gqx; // del-1349-delayL
    case 0x19A00729: return &hTable_VFBC1AYT; // del-1349-delayR
    case 0x584C8281: return &hTable_bkrY9PzY; // del-1428-delayL
    case 0x54BF59F6: return &hTable_CLjbKCjX; // del-1428-delayR
    case 0xBCE693A: return &hTable_Km1SNKyV; // del-1507-delayL
    case 0x95A380B3: return &hTable_rzixzLEt; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iTekpQ5D_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7Zcbdh8s_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_but82jKR_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Eh3VwBFa_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WG80Py5o_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cWrUl0l1_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SvCCjORg_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HnauRGlw_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nitMiGOu_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b1aTLUXH_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wiIFFWzj_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YJQmshYQ_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KLjcMVEH_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_N4rp0U7x_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jzMrWg4x_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RTNuNln0_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qw9S0PbQ_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QQJbQcPZ_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xyMtw8qT_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iy8b5M1Z_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R7ZHqxyS_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aKt8vofa_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l3zhFGK2_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WhcyzXNg_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A9xaW2os_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dHnXAMaw_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4Z9qqmcE_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3c6O255l_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lBYAlQ7a_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EU9d5Z35_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qDFQwlf6_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rmNEV2TD_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ip85ejWn_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fHW36bUW_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VSJn6NvB_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yFvGxecI_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BW3ArWVc_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sSmzzn8h_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t1Hhj4hL_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OkE06t34_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AwqfwImJ_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o1tRKvJT_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CnFqJLJa_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BMfmRybp_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_q7VjtljZ_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aRwKSAjx_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jwkx6LqQ_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7wFegc84_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NN4sq7aW_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BO78P08o_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HUpHRyHm_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R21RMirD_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FTXCoCZP_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6rPRNRhQ_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nT7jiRgU_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qDFH7X29_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0aI3Hqoq_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X0yXp7gF_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oIF66tto_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bHfDdR65_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ibfo7HYl_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ba5FQief_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZL6Yg586_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9amjkNXX_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_NM6acaFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CeBLiXZC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_2f0nSEdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_udohSKpx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_LvVjHrVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nfpfRz0D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_KQMSurnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MlwQmtsl_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j4bB033w_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FU9HLZXh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0mPybXcm_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_dJft9FAV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_X5QTJyHK, 0, m, &cSlice_X5QTJyHK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Jfj5D3K8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_X5QTJyHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MW0NEMoC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MW0NEMoC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_vRh2iLfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MW0NEMoC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_MW0NEMoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_A9xaW2os_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_slhxln3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4mO6WDom_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_tn2lfbsG, 0, m, &cIf_tn2lfbsG_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_tn2lfbsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jdHaIWeA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_3GoU4Nr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_jbncOzEk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_skg49ZlV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_lA12Y7lL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_t0V6F5vQ, HV_BINOP_POW, 0, m, &cBinop_t0V6F5vQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t0V6F5vQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZrQVmGUI, 0, m, &cIf_ZrQVmGUI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bhlrHuNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_DILl9N4K_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JsI0kIOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3GoU4Nr5, 0, m, &cIf_3GoU4Nr5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Nyo6QOq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MzxGFJbn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MzxGFJbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3GoU4Nr5, 1, m, &cIf_3GoU4Nr5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_skg49ZlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_bhlrHuNs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jbncOzEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ZrQVmGUI, 0, m, &cIf_ZrQVmGUI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DILl9N4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t0V6F5vQ, HV_BINOP_POW, 1, m, &cBinop_t0V6F5vQ_sendMessage);
  cMsg_lA12Y7lL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_ZrQVmGUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_VjwpR1c3, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_4mO6WDom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tn2lfbsG, 1, m, &cIf_tn2lfbsG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jdHaIWeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_swXUVnjK, HV_BINOP_GREATER_THAN, 1, m, &cBinop_swXUVnjK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AOYXGAiQ, HV_BINOP_EQ, 1, m, &cBinop_AOYXGAiQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6UP8ZkX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VS5rYEs7, HV_BINOP_ADD, 0, m, &cBinop_VS5rYEs7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VS5rYEs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nyo6QOq1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JsI0kIOu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_swXUVnjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZrQVmGUI, 1, m, &cIf_ZrQVmGUI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AOYXGAiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lyz3mRFR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Lyz3mRFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_VjwpR1c3, m);
}

void Heavy_WSTD_DL3Y::cCast_uUTTo7zi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VS5rYEs7, HV_BINOP_ADD, 1, m, &cBinop_VS5rYEs7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_swXUVnjK, HV_BINOP_GREATER_THAN, 0, m, &cBinop_swXUVnjK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AOYXGAiQ, HV_BINOP_EQ, 0, m, &cBinop_AOYXGAiQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hKI1omFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_slhxln3W, 0, m, &cVar_slhxln3W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CtSGgSCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6UP8ZkX3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_LDRqaBeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5xmreHbN_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_24V0HBxx, 0, m, &cIf_24V0HBxx_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_24V0HBxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_RDswtgyR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_KTk1ffSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_lsWMvwHM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ns19mBNL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_c4hdOqyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TGvFAfzA, HV_BINOP_POW, 0, m, &cBinop_TGvFAfzA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TGvFAfzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DxavvTPC, 0, m, &cIf_DxavvTPC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eGHxT3sM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_GyWwHSQK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HEx5xATR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4ku05bHP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RtRg8iDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KTk1ffSM, 0, m, &cIf_KTk1ffSM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4ku05bHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KTk1ffSM, 1, m, &cIf_KTk1ffSM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ns19mBNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_eGHxT3sM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lsWMvwHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_DxavvTPC, 0, m, &cIf_DxavvTPC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GyWwHSQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TGvFAfzA, HV_BINOP_POW, 1, m, &cBinop_TGvFAfzA_sendMessage);
  cMsg_c4hdOqyq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_DxavvTPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mcKwUMUh_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zgBgmCuD_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_CGG1XR87_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_5xmreHbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_24V0HBxx, 1, m, &cIf_24V0HBxx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RDswtgyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VglbAqvK, HV_BINOP_GREATER_THAN, 1, m, &cBinop_VglbAqvK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FsJEsu0F, HV_BINOP_EQ, 1, m, &cBinop_FsJEsu0F_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PAw2ywki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1sGYrgpb, HV_BINOP_ADD, 0, m, &cBinop_1sGYrgpb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1sGYrgpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HEx5xATR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RtRg8iDR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VglbAqvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DxavvTPC, 1, m, &cIf_DxavvTPC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FsJEsu0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WYu3GK6J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_WYu3GK6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mcKwUMUh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zgBgmCuD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_CGG1XR87_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ILj0qXLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LDRqaBeT, 0, m, &cVar_LDRqaBeT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_V0fxtWeK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PAw2ywki_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_W1aOoOem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1sGYrgpb, HV_BINOP_ADD, 1, m, &cBinop_1sGYrgpb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VglbAqvK, HV_BINOP_GREATER_THAN, 0, m, &cBinop_VglbAqvK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FsJEsu0F, HV_BINOP_EQ, 0, m, &cBinop_FsJEsu0F_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_tSpa8K8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eZiikBFs_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_aIreGWdO, 0, m, &cIf_aIreGWdO_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_aIreGWdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YALAfcwf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_sNTOeslz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_kk1ULuXa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Un6mQU3R_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_9EKer9wH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sB2VMDM5, HV_BINOP_POW, 0, m, &cBinop_sB2VMDM5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sB2VMDM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DMXDfLOV, 0, m, &cIf_DMXDfLOV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uirH7nyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_HCC5VmyZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_e7kCj8hS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Sm33s2xt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_snZkZ8xZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sNTOeslz, 0, m, &cIf_sNTOeslz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Sm33s2xt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sNTOeslz, 1, m, &cIf_sNTOeslz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Un6mQU3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_uirH7nyf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kk1ULuXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_DMXDfLOV, 0, m, &cIf_DMXDfLOV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HCC5VmyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sB2VMDM5, HV_BINOP_POW, 1, m, &cBinop_sB2VMDM5_sendMessage);
  cMsg_9EKer9wH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_DMXDfLOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Wn8wvYRI, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_eZiikBFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aIreGWdO, 1, m, &cIf_aIreGWdO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YALAfcwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b7bYCJYZ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_b7bYCJYZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UJcNyWNj, HV_BINOP_EQ, 1, m, &cBinop_UJcNyWNj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JMhDVzkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nAUf44ZC, HV_BINOP_ADD, 0, m, &cBinop_nAUf44ZC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nAUf44ZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e7kCj8hS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_snZkZ8xZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b7bYCJYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DMXDfLOV, 1, m, &cIf_DMXDfLOV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UJcNyWNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ok99c6Km_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Ok99c6Km_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Wn8wvYRI, m);
}

void Heavy_WSTD_DL3Y::cCast_TduksJh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tSpa8K8l, 0, m, &cVar_tSpa8K8l_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_n4jyNJxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JMhDVzkr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_8wwroz6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nAUf44ZC, HV_BINOP_ADD, 1, m, &cBinop_nAUf44ZC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_b7bYCJYZ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_b7bYCJYZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UJcNyWNj, HV_BINOP_EQ, 0, m, &cBinop_UJcNyWNj_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_j5JMxdDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_W86PE782, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_XiPdytgl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Yl6L9LUA, 0, m, &cSlice_Yl6L9LUA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Y84i9K94_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Yl6L9LUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_O4vbbxPw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_O4vbbxPw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_eUHb5rIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_O4vbbxPw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_O4vbbxPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_l3zhFGK2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Y84i9K94_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_iOK9D8PJ, 0, m, &cSlice_iOK9D8PJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dJft9FAV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_iOK9D8PJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MDmq4M7k_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MDmq4M7k_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_0mwQgrcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MDmq4M7k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_MDmq4M7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4Z9qqmcE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Jfj5D3K8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dqLFwkio, 0, m, &cSlice_dqLFwkio_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8yY01y37_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_dqLFwkio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_J9MLwNbZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_J9MLwNbZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_LrfnwP1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_J9MLwNbZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_J9MLwNbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WhcyzXNg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8yY01y37_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hufttvo2, 0, m, &cSlice_hufttvo2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_hufttvo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JN8lXOVe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JN8lXOVe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_yLKjRODC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JN8lXOVe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_JN8lXOVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dHnXAMaw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_0KZNijOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I6wprYIi, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_a8DyEZvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vTfbv1xq, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_KHATIcCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cvU3u3b4, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_IaariKUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_knz5PubY, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_21BrcpGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jFr06Sw1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_7OegB3yr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KS3BCmkz_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_KS3BCmkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hQr4HLOQ, HV_BINOP_DIVIDE, 1, m, &cBinop_hQr4HLOQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qIE0uLIX_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_4yH2OZrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_5MPLOfj8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0KUZhPJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_4yH2OZrE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5MPLOfj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hQr4HLOQ, HV_BINOP_DIVIDE, 0, m, &cBinop_hQr4HLOQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qIE0uLIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0KUZhPJu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hQr4HLOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zDVHL04v, HV_BINOP_MULTIPLY, 1, m, &cBinop_zDVHL04v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zDVHL04v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TPgyGrg1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V9UJ9h1i_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Uky2YJVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_brhNs54b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_pOuHxN2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UGfSIAfQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bpXC2hxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_dnIeKpxC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dnIeKpxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zDVHL04v, HV_BINOP_MULTIPLY, 0, m, &cBinop_zDVHL04v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u9vUYkLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_g2upBmbi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g2upBmbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2KH0AETX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KrFqtRUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_avZxaQtb, 1, m, &cVar_avZxaQtb_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_avZxaQtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3rVxbWP5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3fQzVvf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ru8pw08y, HV_BINOP_MULTIPLY, 1, m, &cBinop_ru8pw08y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LM1jBmC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3fQzVvf7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Si4Y3OUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_eimfOK9i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eimfOK9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RdvjW3Sm, HV_BINOP_MULTIPLY, 1, m, &cBinop_RdvjW3Sm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jhNfOJIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TPADUDmB, HV_BINOP_MULTIPLY, 1, m, &cBinop_TPADUDmB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vhdVQIp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jhNfOJIh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_v5a8eH2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AkOY2QXc, HV_BINOP_MULTIPLY, 1, m, &cBinop_AkOY2QXc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9LGUR5pX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ULOvgV6W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ULOvgV6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dBVb3KwG, HV_BINOP_MULTIPLY, 1, m, &cBinop_dBVb3KwG_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_YVlpIwUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DiZhGzMB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_bpXC2hxb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A2BgwJLL_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_KQu9AF0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_u9vUYkLB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_V9UJ9h1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_pOuHxN2J_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TPgyGrg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Uky2YJVo_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_brhNs54b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EU9d5Z35_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_UGfSIAfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lBYAlQ7a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_q8xcXflJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3c6O255l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_2KH0AETX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_j70Ug2OZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_j70Ug2OZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_raLUnb9g, HV_BINOP_MULTIPLY, 1, m, &cBinop_raLUnb9g_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_raLUnb9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pS71OikA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pS71OikA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_q8xcXflJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_3rVxbWP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Q56ET9nG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q56ET9nG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z4w6uaCr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FXEyOCbR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l4fo93Ee_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kH3GMJMB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AMJHCszI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4RzsKx3O_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ru8pw08y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0KZNijOP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_RdvjW3Sm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a8DyEZvJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TPADUDmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KHATIcCQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AkOY2QXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IaariKUd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dBVb3KwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_21BrcpGW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qNegzbx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YVlpIwUP, 0, m, &cVar_YVlpIwUP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1GEbtavK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KQu9AF0Q, 1, m, &cVar_KQu9AF0Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AMJHCszI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RdvjW3Sm, HV_BINOP_MULTIPLY, 0, m, &cBinop_RdvjW3Sm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FXEyOCbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dBVb3KwG, HV_BINOP_MULTIPLY, 0, m, &cBinop_dBVb3KwG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kH3GMJMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TPADUDmB, HV_BINOP_MULTIPLY, 0, m, &cBinop_TPADUDmB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_z4w6uaCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_4RzsKx3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ru8pw08y, HV_BINOP_MULTIPLY, 0, m, &cBinop_ru8pw08y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_l4fo93Ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AkOY2QXc, HV_BINOP_MULTIPLY, 0, m, &cBinop_AkOY2QXc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DiZhGzMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KQu9AF0Q, 0, m, &cVar_KQu9AF0Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_A2BgwJLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_avZxaQtb, 0, m, &cVar_avZxaQtb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LcWcXYqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qs1dRYiM, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_yzNAjqDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kDXkBOSj, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Qpx4HIiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ilkqabTU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zXPQDesk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mr2uuxAO, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_jQQxU3bI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JKsKUdIf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_JKsKUdIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YvRM2XRe, HV_BINOP_DIVIDE, 1, m, &cBinop_YvRM2XRe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zeMWPGyW_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_3rKBWuT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_d85viLqp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UwxGXJaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_3rKBWuT2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d85viLqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YvRM2XRe, HV_BINOP_DIVIDE, 0, m, &cBinop_YvRM2XRe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zeMWPGyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UwxGXJaL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YvRM2XRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Bw5EsH2, HV_BINOP_MULTIPLY, 1, m, &cBinop_1Bw5EsH2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1Bw5EsH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cnrvOiQq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2E1elJiM_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_WA1RnFPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PG98QzM0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_VMKJtxr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mztds0Wa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7vuqDYc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_MD3DWALD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MD3DWALD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Bw5EsH2, HV_BINOP_MULTIPLY, 0, m, &cBinop_1Bw5EsH2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lWZ6W7lw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_2vaI2sZY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2vaI2sZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2Pz9BKgh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ODxdjk8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_575DFFeU, HV_BINOP_MULTIPLY, 1, m, &cBinop_575DFFeU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qFIX1Agh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IHb0aMKh, 1, m, &cVar_IHb0aMKh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HEtYx2Ov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F8XoCP6o, HV_BINOP_MULTIPLY, 1, m, &cBinop_F8XoCP6o_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xjZ4Zu03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fB4ww6xN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fB4ww6xN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dsuPEG4O, HV_BINOP_MULTIPLY, 1, m, &cBinop_dsuPEG4O_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_IHb0aMKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KO4YLctI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_BX1c18fq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QTtKM8q8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_7vuqDYc5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EtWONQux_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_cU3R3pdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lWZ6W7lw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2E1elJiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_VMKJtxr7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cnrvOiQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_WA1RnFPg_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_PG98QzM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ip85ejWn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_mztds0Wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rmNEV2TD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_BftpgpPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qDFQwlf6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_2Pz9BKgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SE2lb3aF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SE2lb3aF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z5IWpqhm, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z5IWpqhm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z5IWpqhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xylHPqNV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xylHPqNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BftpgpPM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_KO4YLctI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_w1FQV0nz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w1FQV0nz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uxagdDcU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_94xgI4ew_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qFZaxrLO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kbI8qZKf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KstAfwlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LcWcXYqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_575DFFeU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yzNAjqDw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_F8XoCP6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qpx4HIiF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dsuPEG4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zXPQDesk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_4JyYaUGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BX1c18fq, 0, m, &cVar_BX1c18fq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CthKcHIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cU3R3pdQ, 1, m, &cVar_cU3R3pdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EtWONQux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IHb0aMKh, 0, m, &cVar_IHb0aMKh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QTtKM8q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cU3R3pdQ, 0, m, &cVar_cU3R3pdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_94xgI4ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F8XoCP6o, HV_BINOP_MULTIPLY, 0, m, &cBinop_F8XoCP6o_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kbI8qZKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KstAfwlN, HV_BINOP_MULTIPLY, 0, m, &cBinop_KstAfwlN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uxagdDcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dsuPEG4O, HV_BINOP_MULTIPLY, 0, m, &cBinop_dsuPEG4O_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qFZaxrLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_575DFFeU, HV_BINOP_MULTIPLY, 0, m, &cBinop_575DFFeU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wUPv5qy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wK6nvYIF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_pzcBB8C8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z0kfwbHu, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6ugUrzyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FL2esOLa, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_XZw1brsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_70Lbg4tp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bK5JL5Va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bym6TQ35, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_oXTES7OJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6hrNijWf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_6hrNijWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z1GnK64j, HV_BINOP_DIVIDE, 1, m, &cBinop_Z1GnK64j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9q4vcnbb_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_7B6W2W0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_qcPJgGSQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HS0ikfoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_7B6W2W0n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qcPJgGSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z1GnK64j, HV_BINOP_DIVIDE, 0, m, &cBinop_Z1GnK64j_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9q4vcnbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HS0ikfoX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Z1GnK64j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sxtQxfNx, HV_BINOP_MULTIPLY, 1, m, &cBinop_sxtQxfNx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sxtQxfNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8hC1YMSS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nenj2IoX_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_5oA3AuLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4AD0JUNc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_Cg6R1Fz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cNPfKeEV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fvCjOoPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_HJD0Gd3S_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HJD0Gd3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sxtQxfNx, HV_BINOP_MULTIPLY, 0, m, &cBinop_sxtQxfNx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0rzfJZ2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_DXbs6cjo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DXbs6cjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qptDrx4q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gsl0APnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oYjT3kGw, HV_BINOP_MULTIPLY, 1, m, &cBinop_oYjT3kGw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rjiJnnah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CNkPUzhu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CNkPUzhu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gsl0APnW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wesYtAxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QkH5qzE6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QkH5qzE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_buzQcm7E, HV_BINOP_MULTIPLY, 1, m, &cBinop_buzQcm7E_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fXtWXUbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5AIB8g0d, HV_BINOP_MULTIPLY, 1, m, &cBinop_5AIB8g0d_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fJcTlWxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Kb1RVOzE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Kb1RVOzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_fXtWXUbT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jxvluvrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_alngRCJ4, 1, m, &cVar_alngRCJ4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Xxw4btRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SEvr1nwH, HV_BINOP_MULTIPLY, 1, m, &cBinop_SEvr1nwH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BR55Gw7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vpUqhPco_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vpUqhPco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_paej8YCT, HV_BINOP_MULTIPLY, 1, m, &cBinop_paej8YCT_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_alngRCJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TBOtp7Ec_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_DjLqCqSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ov605AAc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_fvCjOoPM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AQTUGSdf_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_NgBm4msn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_0rzfJZ2y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nenj2IoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Cg6R1Fz6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8hC1YMSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_5oA3AuLq_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_4AD0JUNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yFvGxecI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_cNPfKeEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VSJn6NvB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_0BE7YwoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fHW36bUW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_qptDrx4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HkOxs91O_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HkOxs91O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IMV961Iv, HV_BINOP_MULTIPLY, 1, m, &cBinop_IMV961Iv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IMV961Iv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_y92DsJO0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y92DsJO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0BE7YwoT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_TBOtp7Ec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_flsnI9l9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_flsnI9l9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Opi5wig0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XSRdhzsR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lP447xmq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gw6eUnal_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OHbT9cHu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RyODmhqt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oYjT3kGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wUPv5qy7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_buzQcm7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pzcBB8C8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5AIB8g0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6ugUrzyI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SEvr1nwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XZw1brsJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_paej8YCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bK5JL5Va_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_22NNGpDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DjLqCqSv, 0, m, &cVar_DjLqCqSv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xjq3f7ro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NgBm4msn, 1, m, &cVar_NgBm4msn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RyODmhqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oYjT3kGw, HV_BINOP_MULTIPLY, 0, m, &cBinop_oYjT3kGw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lP447xmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SEvr1nwH, HV_BINOP_MULTIPLY, 0, m, &cBinop_SEvr1nwH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OHbT9cHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_buzQcm7E, HV_BINOP_MULTIPLY, 0, m, &cBinop_buzQcm7E_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XSRdhzsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_paej8YCT, HV_BINOP_MULTIPLY, 0, m, &cBinop_paej8YCT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Gw6eUnal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5AIB8g0d, HV_BINOP_MULTIPLY, 0, m, &cBinop_5AIB8g0d_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Opi5wig0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_AQTUGSdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_alngRCJ4, 0, m, &cVar_alngRCJ4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ov605AAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NgBm4msn, 0, m, &cVar_NgBm4msn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mcKwUMUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j5JMxdDP, 1, m, &cIf_j5JMxdDP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0OkgUuJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_W86PE782, m);
}

void Heavy_WSTD_DL3Y::cBinop_zgBgmCuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0OkgUuJm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CGG1XR87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j5JMxdDP, 0, m, &cIf_j5JMxdDP_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_sb5KlwRp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MfR8pJ76, 0, m, &cSlice_MfR8pJ76_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7yJd6DqE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_MfR8pJ76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Yhd00H3K_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Yhd00H3K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_mvNnx7Xc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Yhd00H3K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Yhd00H3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t1Hhj4hL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_12UxQ21Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JtFxxgcK_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_lB3Uv6II, 0, m, &cIf_lB3Uv6II_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_lB3Uv6II_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lRtKhwJc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_R34oKHNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_04pgiT2I_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_eAPzAF92_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_wq5FV8HZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_g3n2B0az, HV_BINOP_POW, 0, m, &cBinop_g3n2B0az_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g3n2B0az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TuwKMYrC, 0, m, &cIf_TuwKMYrC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L5kLsKlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_9zM9mPPW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bSbYTcXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_x8pmCjJJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2IeVWYzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R34oKHNn, 0, m, &cIf_R34oKHNn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x8pmCjJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R34oKHNn, 1, m, &cIf_R34oKHNn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eAPzAF92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_L5kLsKlV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_04pgiT2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_TuwKMYrC, 0, m, &cIf_TuwKMYrC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9zM9mPPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g3n2B0az, HV_BINOP_POW, 1, m, &cBinop_g3n2B0az_sendMessage);
  cMsg_wq5FV8HZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_TuwKMYrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_cGjQBxew, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_JtFxxgcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lB3Uv6II, 1, m, &cIf_lB3Uv6II_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lRtKhwJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hhL3pet9, HV_BINOP_GREATER_THAN, 1, m, &cBinop_hhL3pet9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8z84LUyh, HV_BINOP_EQ, 1, m, &cBinop_8z84LUyh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3PagYYLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mb3oE3v8, HV_BINOP_ADD, 0, m, &cBinop_mb3oE3v8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mb3oE3v8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bSbYTcXt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2IeVWYzP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hhL3pet9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TuwKMYrC, 1, m, &cIf_TuwKMYrC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8z84LUyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U7G5A2Wz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_U7G5A2Wz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_cGjQBxew, m);
}

void Heavy_WSTD_DL3Y::cCast_ZYOXQ19R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3PagYYLt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ml5kOm6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mb3oE3v8, HV_BINOP_ADD, 1, m, &cBinop_mb3oE3v8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hhL3pet9, HV_BINOP_GREATER_THAN, 0, m, &cBinop_hhL3pet9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8z84LUyh, HV_BINOP_EQ, 0, m, &cBinop_8z84LUyh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WCzMOfXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_12UxQ21Y, 0, m, &cVar_12UxQ21Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7E1XdGHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Tn2VESCZ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Ygyl14yl, 0, m, &cIf_Ygyl14yl_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Ygyl14yl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VSOYOhkj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_VOnX6RRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_uNfDUvyN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_3fo26nOi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_yVri6ogh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LvBViZdD, HV_BINOP_POW, 0, m, &cBinop_LvBViZdD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LvBViZdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7CBWkL4a, 0, m, &cIf_7CBWkL4a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yzDkdyl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_WdYN6Eep_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TbO0AeV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GVKxtdzZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_n5DEdOZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VOnX6RRg, 0, m, &cIf_VOnX6RRg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GVKxtdzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VOnX6RRg, 1, m, &cIf_VOnX6RRg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3fo26nOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_yzDkdyl6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uNfDUvyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_7CBWkL4a, 0, m, &cIf_7CBWkL4a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WdYN6Eep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LvBViZdD, HV_BINOP_POW, 1, m, &cBinop_LvBViZdD_sendMessage);
  cMsg_yVri6ogh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_7CBWkL4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lijZuOJx_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Rt8s4O49_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_DihNk2qH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_Tn2VESCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ygyl14yl, 1, m, &cIf_Ygyl14yl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VSOYOhkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b3sXKXwx, HV_BINOP_GREATER_THAN, 1, m, &cBinop_b3sXKXwx_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cvTLQTCc, HV_BINOP_EQ, 1, m, &cBinop_cvTLQTCc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_z7OQRLlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_w1R9K5iH, HV_BINOP_ADD, 0, m, &cBinop_w1R9K5iH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w1R9K5iH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TbO0AeV1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n5DEdOZc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b3sXKXwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7CBWkL4a, 1, m, &cIf_7CBWkL4a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cvTLQTCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tjESArRx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_tjESArRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lijZuOJx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Rt8s4O49_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_DihNk2qH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MST2fGEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7E1XdGHn, 0, m, &cVar_7E1XdGHn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mwSJ4mEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z7OQRLlK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ped9OBud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w1R9K5iH, HV_BINOP_ADD, 1, m, &cBinop_w1R9K5iH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_b3sXKXwx, HV_BINOP_GREATER_THAN, 0, m, &cBinop_b3sXKXwx_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cvTLQTCc, HV_BINOP_EQ, 0, m, &cBinop_cvTLQTCc_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_cIQFoNpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Szv2QJ4s_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qTpIXfd7, 0, m, &cIf_qTpIXfd7_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_qTpIXfd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8JSsRqTW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_fYVDozGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_zZEqxfrL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_WoIP0vWu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_O8E3iurP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qEvvKoDX, HV_BINOP_POW, 0, m, &cBinop_qEvvKoDX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qEvvKoDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xmQJHb4B, 0, m, &cIf_xmQJHb4B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XPAKZGdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_svLW6CvM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4DoOea5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dpXBM3NK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7Tv0fUfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fYVDozGx, 0, m, &cIf_fYVDozGx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dpXBM3NK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fYVDozGx, 1, m, &cIf_fYVDozGx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WoIP0vWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_XPAKZGdT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zZEqxfrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_xmQJHb4B, 0, m, &cIf_xmQJHb4B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_svLW6CvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qEvvKoDX, HV_BINOP_POW, 1, m, &cBinop_qEvvKoDX_sendMessage);
  cMsg_O8E3iurP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_xmQJHb4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_WYEtuFBT, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_Szv2QJ4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qTpIXfd7, 1, m, &cIf_qTpIXfd7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8JSsRqTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aw093SGk, HV_BINOP_GREATER_THAN, 1, m, &cBinop_aw093SGk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yTBUc0nx, HV_BINOP_EQ, 1, m, &cBinop_yTBUc0nx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GhfH4Um6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9JaygyU2, HV_BINOP_ADD, 0, m, &cBinop_9JaygyU2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9JaygyU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4DoOea5w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7Tv0fUfN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aw093SGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xmQJHb4B, 1, m, &cIf_xmQJHb4B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yTBUc0nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WAD1kWET_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_WAD1kWET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WYEtuFBT, m);
}

void Heavy_WSTD_DL3Y::cCast_9Xg5FgMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GhfH4Um6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_rMUamBgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9JaygyU2, HV_BINOP_ADD, 1, m, &cBinop_9JaygyU2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aw093SGk, HV_BINOP_GREATER_THAN, 0, m, &cBinop_aw093SGk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yTBUc0nx, HV_BINOP_EQ, 0, m, &cBinop_yTBUc0nx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7WtxtOJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cIQFoNpQ, 0, m, &cVar_cIQFoNpQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_TzScbUvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Z4Zl93tK, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_iIr2CS6q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5uQrIjET, 0, m, &cSlice_5uQrIjET_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8agMhABx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_5uQrIjET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Q4FfbHZi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Q4FfbHZi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_v9zvijTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Q4FfbHZi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Q4FfbHZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BW3ArWVc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8agMhABx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NbSvJyFh, 0, m, &cSlice_NbSvJyFh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sb5KlwRp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_NbSvJyFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_o5rsnZZm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_o5rsnZZm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_THS3pkUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_o5rsnZZm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_o5rsnZZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AwqfwImJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_7yJd6DqE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MqJLvnl2, 0, m, &cSlice_MqJLvnl2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_m0dzdIie_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_MqJLvnl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4MuGZ4cF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4MuGZ4cF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ZaHymWZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4MuGZ4cF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_4MuGZ4cF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sSmzzn8h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_m0dzdIie_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CXNbEvTW, 0, m, &cSlice_CXNbEvTW_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_CXNbEvTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Ali2hMUe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Ali2hMUe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_eVnSRCCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ali2hMUe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Ali2hMUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OkE06t34_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_EURiNEID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NcFBbVig, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_aKATXr2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XzNvP8n7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ziZaOgWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZepcElHM, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qkSEAYTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f0o5g4BF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ryCdV2qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_97GiIisa, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qIDjItMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KIXolKLy_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_KIXolKLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EPG709YP, HV_BINOP_DIVIDE, 1, m, &cBinop_EPG709YP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z9vJqN5H_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Q0qrPcdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_j1xnvWMU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aTLEPtjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Q0qrPcdL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_j1xnvWMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EPG709YP, HV_BINOP_DIVIDE, 0, m, &cBinop_EPG709YP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_z9vJqN5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aTLEPtjX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_EPG709YP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lIPXNBdJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_lIPXNBdJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lIPXNBdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iLCSVOJK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_18mvAYg4_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_0rbRMCA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2TYbjzFf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_bv9fSVh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vZU56vC6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ya9VQnE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_MDSKACj5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MDSKACj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lIPXNBdJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_lIPXNBdJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GKAR6bir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_0uiyh7Mn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0uiyh7Mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1kGMkNlF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LHzxLCjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2PomZlgo, 1, m, &cVar_2PomZlgo_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_2PomZlgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dc8Lu24u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5PF5feZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2sOgt4Br, HV_BINOP_MULTIPLY, 1, m, &cBinop_2sOgt4Br_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T0lX6mSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5PF5feZa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uoCi1SFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4LT0SABV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4LT0SABV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uiZKOsFk, HV_BINOP_MULTIPLY, 1, m, &cBinop_uiZKOsFk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2ONtJWkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vxPCdxuw, HV_BINOP_MULTIPLY, 1, m, &cBinop_vxPCdxuw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fDKO1i3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2ONtJWkm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_idOtp5Ol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bBqQdf7z, HV_BINOP_MULTIPLY, 1, m, &cBinop_bBqQdf7z_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UbqFmKY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_B60aBDT0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B60aBDT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_srsnJC2J, HV_BINOP_MULTIPLY, 1, m, &cBinop_srsnJC2J_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_0AjaKOCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uqaMFxie_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ya9VQnE1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X0gHAY8i_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_bvpXtVjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_GKAR6bir_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_18mvAYg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_bv9fSVh1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iLCSVOJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_0rbRMCA6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_2TYbjzFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BMfmRybp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_vZU56vC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CnFqJLJa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_03Rtd5Mz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_o1tRKvJT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_1kGMkNlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_DyxGReuI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DyxGReuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cKOwQ6aT, HV_BINOP_MULTIPLY, 1, m, &cBinop_cKOwQ6aT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cKOwQ6aT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Cd5MvDgC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Cd5MvDgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_03Rtd5Mz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Dc8Lu24u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lHBgDg4F_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lHBgDg4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cEZjUOCb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ICdclBBr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hfrwtck9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dUVelXJ0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0HFVfCkz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GQDyILHc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2sOgt4Br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EURiNEID_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_uiZKOsFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aKATXr2X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vxPCdxuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ziZaOgWj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bBqQdf7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qkSEAYTj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_srsnJC2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ryCdV2qh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_gNWeFgZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0AjaKOCA, 0, m, &cVar_0AjaKOCA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3LDrjVut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bvpXtVjF, 1, m, &cVar_bvpXtVjF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dUVelXJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vxPCdxuw, HV_BINOP_MULTIPLY, 0, m, &cBinop_vxPCdxuw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cEZjUOCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_GQDyILHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2sOgt4Br, HV_BINOP_MULTIPLY, 0, m, &cBinop_2sOgt4Br_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Hfrwtck9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bBqQdf7z, HV_BINOP_MULTIPLY, 0, m, &cBinop_bBqQdf7z_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0HFVfCkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uiZKOsFk, HV_BINOP_MULTIPLY, 0, m, &cBinop_uiZKOsFk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ICdclBBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_srsnJC2J, HV_BINOP_MULTIPLY, 0, m, &cBinop_srsnJC2J_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_X0gHAY8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2PomZlgo, 0, m, &cVar_2PomZlgo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uqaMFxie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bvpXtVjF, 0, m, &cVar_bvpXtVjF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ndhRxN3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kCNhuBUy, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_cBzFoeS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tCDmgDXu, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_r4CmIsoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PITmoIZn, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_V8UqBpkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WXVJivOp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RbLDXUXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UcDC42Tk_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_UcDC42Tk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WWtFhVF3, HV_BINOP_DIVIDE, 1, m, &cBinop_WWtFhVF3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DPg91hD7_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_YMrSYwK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_eKmGXMIv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vBq73EQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_YMrSYwK0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eKmGXMIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WWtFhVF3, HV_BINOP_DIVIDE, 0, m, &cBinop_WWtFhVF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DPg91hD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vBq73EQ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WWtFhVF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SjxKMMGK, HV_BINOP_MULTIPLY, 1, m, &cBinop_SjxKMMGK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SjxKMMGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iUDJ9RTu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y6rCIO8E_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Ib9qrA76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jFG9GCcK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_x8fGwJLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_va0rVMgX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OWGKZd9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_HD4J60B4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HD4J60B4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SjxKMMGK, HV_BINOP_MULTIPLY, 0, m, &cBinop_SjxKMMGK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hKGsq4ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_yiHIBIzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yiHIBIzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S60mX08f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ykCv7pdb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAof12Md, HV_BINOP_MULTIPLY, 1, m, &cBinop_xAof12Md_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6fnGT5d0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VUx2jcoR, 1, m, &cVar_VUx2jcoR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ySiP2Opj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xNQKtOXH, HV_BINOP_MULTIPLY, 1, m, &cBinop_xNQKtOXH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_X4Dj4JEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jcaP7Jul_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jcaP7Jul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a765pIG5, HV_BINOP_MULTIPLY, 1, m, &cBinop_a765pIG5_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_VUx2jcoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NSoXAhZ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_K8H53V02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0msE8EFv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_OWGKZd9Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MLwy3SYq_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mcKjSTdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_hKGsq4ib_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_y6rCIO8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_x8fGwJLY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iUDJ9RTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Ib9qrA76_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_jFG9GCcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jwkx6LqQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_va0rVMgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aRwKSAjx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_6B2iSO4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_q7VjtljZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_S60mX08f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Q49E9Gm2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q49E9Gm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FYBJy8bb, HV_BINOP_MULTIPLY, 1, m, &cBinop_FYBJy8bb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FYBJy8bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hBNHCmUt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hBNHCmUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6B2iSO4Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_NSoXAhZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IaKvvGRx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IaKvvGRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ahl2R0eF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SaIdgKtF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vF6E3fjW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GyR4Pkvt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jw7ZXvnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ndhRxN3i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_xAof12Md_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cBzFoeS5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_xNQKtOXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r4CmIsoY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_a765pIG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V8UqBpkT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_93q3kUdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K8H53V02, 0, m, &cVar_K8H53V02_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rr6WnidU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mcKjSTdE, 1, m, &cVar_mcKjSTdE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MLwy3SYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VUx2jcoR, 0, m, &cVar_VUx2jcoR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0msE8EFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mcKjSTdE, 0, m, &cVar_mcKjSTdE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SaIdgKtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xNQKtOXH, HV_BINOP_MULTIPLY, 0, m, &cBinop_xNQKtOXH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GyR4Pkvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jw7ZXvnP, HV_BINOP_MULTIPLY, 0, m, &cBinop_Jw7ZXvnP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ahl2R0eF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a765pIG5, HV_BINOP_MULTIPLY, 0, m, &cBinop_a765pIG5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vF6E3fjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAof12Md, HV_BINOP_MULTIPLY, 0, m, &cBinop_xAof12Md_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Pjwl5dEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xNt8xlfB, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_chHpDybM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VMq9IJQU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_X5cOfH99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ce9s4Hqw, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_jqhclHQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VM32LE3s, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NMKVCFp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1dn2ZUdU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uhTjsdIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_i24HVAAy_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_i24HVAAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a1PtdLvk, HV_BINOP_DIVIDE, 1, m, &cBinop_a1PtdLvk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bsa8TuMa_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_69pVzadH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_mjOp0JvK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6KUUHk02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_69pVzadH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mjOp0JvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a1PtdLvk, HV_BINOP_DIVIDE, 0, m, &cBinop_a1PtdLvk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Bsa8TuMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6KUUHk02_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_a1PtdLvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_weLJ8C3U, HV_BINOP_MULTIPLY, 1, m, &cBinop_weLJ8C3U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_weLJ8C3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C14F8k0K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xM9ITBRA_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_YSJ6ZsOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_X9xEjnje_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_a2UWcIxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fx7BQlqI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lcQbxdoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_JduI3wJb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JduI3wJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_weLJ8C3U, HV_BINOP_MULTIPLY, 0, m, &cBinop_weLJ8C3U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1pPDSXHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_61eTKaUr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_61eTKaUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m1tn7mVg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_td9WosJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sLR1EyYJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_sLR1EyYJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2xyZphDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rOMlvbYm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rOMlvbYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_td9WosJZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EiErLO0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BbK3TF2M_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BbK3TF2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wx1eI35P, HV_BINOP_MULTIPLY, 1, m, &cBinop_wx1eI35P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zKVuhlmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jlsRPgA7, HV_BINOP_MULTIPLY, 1, m, &cBinop_jlsRPgA7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8ehzhpc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_k3g5cbKG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k3g5cbKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zKVuhlmb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mJMA0CYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dYtbj4qs, 1, m, &cVar_dYtbj4qs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5o4zCMAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bcW2LJT7, HV_BINOP_MULTIPLY, 1, m, &cBinop_bcW2LJT7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f3QRinX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4pRuKwsr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4pRuKwsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cmho8iaF, HV_BINOP_MULTIPLY, 1, m, &cBinop_cmho8iaF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_dYtbj4qs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yx4OJRkO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_zJKK0H0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bFQi292n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_lcQbxdoN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vYEkhhX2_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_fpVPVmtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_1pPDSXHY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xM9ITBRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_a2UWcIxq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C14F8k0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_YSJ6ZsOm_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_X9xEjnje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BO78P08o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_fx7BQlqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NN4sq7aW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_PA270rnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7wFegc84_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_m1tn7mVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1xuixjF6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1xuixjF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xeUL34IS, HV_BINOP_MULTIPLY, 1, m, &cBinop_xeUL34IS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xeUL34IS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wPxconfh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wPxconfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PA270rnt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Yx4OJRkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_o45IgaZi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o45IgaZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f4TL0Inm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SjjnNqa2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_70diJEdf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1BxT6enM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7iZZCEEu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WCf7GzMW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sLR1EyYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pjwl5dEe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_wx1eI35P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_chHpDybM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jlsRPgA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X5cOfH99_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bcW2LJT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jqhclHQp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cmho8iaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NMKVCFp0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_z1vAain2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zJKK0H0m, 0, m, &cVar_zJKK0H0m_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vShbhoGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fpVPVmtH, 1, m, &cVar_fpVPVmtH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_70diJEdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bcW2LJT7, HV_BINOP_MULTIPLY, 0, m, &cBinop_bcW2LJT7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7iZZCEEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wx1eI35P, HV_BINOP_MULTIPLY, 0, m, &cBinop_wx1eI35P_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SjjnNqa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cmho8iaF, HV_BINOP_MULTIPLY, 0, m, &cBinop_cmho8iaF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1BxT6enM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jlsRPgA7, HV_BINOP_MULTIPLY, 0, m, &cBinop_jlsRPgA7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_f4TL0Inm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_WCf7GzMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sLR1EyYJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_sLR1EyYJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vYEkhhX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dYtbj4qs, 0, m, &cVar_dYtbj4qs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bFQi292n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fpVPVmtH, 0, m, &cVar_fpVPVmtH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lijZuOJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TzScbUvH, 1, m, &cIf_TzScbUvH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eTprA5xs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Z4Zl93tK, m);
}

void Heavy_WSTD_DL3Y::cBinop_Rt8s4O49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eTprA5xs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DihNk2qH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TzScbUvH, 0, m, &cIf_TzScbUvH_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_biqfvRpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pcr5SIS8, HV_BINOP_DIVIDE, 0, m, &cBinop_pcr5SIS8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_olQdH4g6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_30IyXZjo, HV_BINOP_DIVIDE, 1, m, &cBinop_30IyXZjo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pcr5SIS8, HV_BINOP_DIVIDE, 1, m, &cBinop_pcr5SIS8_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_C4dplbDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MzQo6Uj5, HV_BINOP_DIVIDE, 0, m, &cBinop_MzQo6Uj5_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_SLkJR5pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MzQo6Uj5, HV_BINOP_DIVIDE, 1, m, &cBinop_MzQo6Uj5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FU9HLZXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_biqfvRpA, 0, m, &cVar_biqfvRpA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_j4bB033w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_olQdH4g6, 0, m, &cVar_olQdH4g6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0mPybXcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_30IyXZjo, HV_BINOP_DIVIDE, 0, m, &cBinop_30IyXZjo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_30IyXZjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_C4dplbDP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pcr5SIS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_SLkJR5pg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MzQo6Uj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_wSIJMcAO_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ijzUOcTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_RNoLyqpG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uVAO0HzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_9vueFbic_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wSIJMcAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uVAO0HzR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9vueFbic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_ijzUOcTI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RNoLyqpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ggb7jxW8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_qAVGWcS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EtA70B7F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_ztHRwYth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9AJFxr2i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_RB9gw8rI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AzSUMlfM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_IulijYFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XE62qjom_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_8K1lHMHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RdJ7ZF4Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Rn46oavl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6FNvRB9u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Y3rqq0F1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X9yzTv3K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_SKw5e4jd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v4PUC1Ew_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_gDNdjVse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lv7rt2iR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_VHZl2OXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uvNgSNjo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_WrYkEG8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hWehpOU0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_5wvHkT4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_brk1XdeB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_XOMrPVHq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_V8vrSoO5, 0, m, &cSlice_V8vrSoO5_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_V8vrSoO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tAyMT5ww_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tAyMT5ww_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Z3d5nhTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tAyMT5ww_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_tAyMT5ww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FTXCoCZP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_L61SNBtI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_r6tsXFt4, 0, m, &cSlice_r6tsXFt4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_M80OJOZN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_r6tsXFt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jrZHQqzz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jrZHQqzz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_dRzA5jTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jrZHQqzz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_jrZHQqzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HUpHRyHm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4Aypk6mc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YYO4T54u, 0, m, &cSlice_YYO4T54u_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XOMrPVHq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_YYO4T54u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oAsSfbvo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oAsSfbvo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_estm9ecK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oAsSfbvo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_oAsSfbvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6rPRNRhQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vwaBGx7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_g4q3DtZ2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g4q3DtZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_vTllFF8N_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_lmMzD0UI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BYOfG1zh_sendMessage(_c, 0, m);
  cMsg_emICJgGY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_kuocZpFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u0680Fvo_sendMessage(_c, 0, m);
  cMsg_EK6vi0gZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vTllFF8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SIHuON5H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SIHuON5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7Pn4LRLS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nFJDS004_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nFJDS004_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G2aLjPVs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_7Pn4LRLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BWMr6Ym7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BWMr6Ym7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_eKeRtZRo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_G2aLjPVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_I1RI5vtT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I1RI5vtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Si2XrO7i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eKeRtZRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_lmMzD0UI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Si2XrO7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_kuocZpFi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tgsLowuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_78oiGUQ9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_78oiGUQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_9DrGeza0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9DrGeza0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VNzP8osu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VNzP8osu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nzpvNhSe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_az8wdmgg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_az8wdmgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C15h310O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_nzpvNhSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_osWmko9Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_osWmko9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_osesccDL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_C15h310O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2jm4xNno_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2jm4xNno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_t1rHY9QW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t1rHY9QW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MuXGjkBj_sendMessage(_c, 0, m);
  cMsg_jdFAUTFj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_osesccDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_afE5NXZx_sendMessage(_c, 0, m);
  cMsg_5APFBY1j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4acQ0SjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FM6BmVGS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FM6BmVGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_IUE4AUpt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0rFHDOTR_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ZPQnXi2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_76J5XWLY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8gjMl7ZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vRykjz6h_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_vRykjz6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eAN1H865, HV_BINOP_DIVIDE, 1, m, &cBinop_eAN1H865_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IUE4AUpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KKOPgvQB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KKOPgvQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nCNM4r3j, m);
}

void Heavy_WSTD_DL3Y::cMsg_tztf3zgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_efmvmVAK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_efmvmVAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_4acQ0SjL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0rFHDOTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_yrkQtW8f, m);
}

void Heavy_WSTD_DL3Y::cBinop_76J5XWLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_dWTTGHwc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dWTTGHwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eAN1H865, HV_BINOP_DIVIDE, 0, m, &cBinop_eAN1H865_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eAN1H865_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tztf3zgi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Y72hmiGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_aRlTT4zi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aRlTT4zi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zOLSgc3M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tnXh7lSJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_DvmCnoCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_6osjaBdj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BpalQJUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VHB6EaJG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_VHB6EaJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2SvpYIbY, HV_BINOP_DIVIDE, 1, m, &cBinop_2SvpYIbY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zOLSgc3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mtdTTlcX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mtdTTlcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_p65BqMTm, m);
}

void Heavy_WSTD_DL3Y::cMsg_XFeUphkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_k4aZqtVU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k4aZqtVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Y72hmiGw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tnXh7lSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pjTm3lfw, m);
}

void Heavy_WSTD_DL3Y::cBinop_6osjaBdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_px9UgeBh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_px9UgeBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2SvpYIbY, HV_BINOP_DIVIDE, 0, m, &cBinop_2SvpYIbY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2SvpYIbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XFeUphkd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_T9RFLJyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WPA4W2Yi, HV_BINOP_MULTIPLY, 0, m, &cBinop_WPA4W2Yi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Wm6hakuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_J6XHZSjc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_J6XHZSjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZNPIx528_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WPA4W2Yi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_cxY9NKBd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8Ctu0lds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WPA4W2Yi, HV_BINOP_MULTIPLY, 1, m, &cBinop_WPA4W2Yi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZNPIx528_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8Ctu0lds_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cxY9NKBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_St4FK8Jl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_St4FK8Jl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RJm1AsqB_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_k1LGLNE6, m);
}

void Heavy_WSTD_DL3Y::cBinop_RJm1AsqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ki4OCpCU, m);
}

void Heavy_WSTD_DL3Y::cVar_WOkEE4zE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VpANjil6, HV_BINOP_MULTIPLY, 0, m, &cBinop_VpANjil6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7z8mXT0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zzSXZYmv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_zzSXZYmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_98vbB7hY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VpANjil6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_oePb2805_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aJvOpGjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VpANjil6, HV_BINOP_MULTIPLY, 1, m, &cBinop_VpANjil6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_98vbB7hY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_aJvOpGjN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oePb2805_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_jwaDVWN5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jwaDVWN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vE4GozGh_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_3W3OCKMW, m);
}

void Heavy_WSTD_DL3Y::cBinop_vE4GozGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FYTaIjq2, m);
}

void Heavy_WSTD_DL3Y::sEnv_1Xc2WVmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sGALiXBI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AnvBH72I_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_zOMGinkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_KI6ln13d_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_gdkRcRM3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_lsF65kyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LMbKSIjT, HV_BINOP_POW, 0, m, &cBinop_LMbKSIjT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LMbKSIjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cWe0AILI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_xIjqsQRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_CTqSUetj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sGALiXBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_H8RTf7iu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AnvBH72I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zOMGinkr, 0, m, &cIf_zOMGinkr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H8RTf7iu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zOMGinkr, 1, m, &cIf_zOMGinkr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gdkRcRM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_xIjqsQRL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KI6ln13d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_cWe0AILI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CTqSUetj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LMbKSIjT, HV_BINOP_POW, 1, m, &cBinop_LMbKSIjT_sendMessage);
  cMsg_lsF65kyg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_SxEoi12Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U8fP6Ga4, HV_BINOP_MULTIPLY, 0, m, &cBinop_U8fP6Ga4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1WgzSyZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_teIf1v3f_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_teIf1v3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DTHx0TVY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_U8fP6Ga4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qt7ocXYh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QogoLpI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U8fP6Ga4, HV_BINOP_MULTIPLY, 1, m, &cBinop_U8fP6Ga4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DTHx0TVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_QogoLpI7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qt7ocXYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_AzUu5JDF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AzUu5JDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RSFbtU0K_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fe7Aq868, m);
}

void Heavy_WSTD_DL3Y::cBinop_RSFbtU0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HivQpNbB, m);
}

void Heavy_WSTD_DL3Y::cMsg_cWe0AILI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cf4WJnlC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cf4WJnlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Q490Pevp, m);
}

void Heavy_WSTD_DL3Y::sEnv_4Y8LDrh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pvbMrT6L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_832PFjC5_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_2CJNcazt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_oJEo2S8L_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_wZSUFO0k_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_JoCoeqzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_q3AacW9T, HV_BINOP_POW, 0, m, &cBinop_q3AacW9T_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q3AacW9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cNNItFOX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_22yl1Yga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_uVEaCFAO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_832PFjC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2CJNcazt, 0, m, &cIf_2CJNcazt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pvbMrT6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_N0ciRtOJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_N0ciRtOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2CJNcazt, 1, m, &cIf_2CJNcazt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wZSUFO0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_22yl1Yga_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oJEo2S8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_cNNItFOX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_uVEaCFAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q3AacW9T, HV_BINOP_POW, 1, m, &cBinop_q3AacW9T_sendMessage);
  cMsg_JoCoeqzY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_11KsIFvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WqaAgiRq, HV_BINOP_MULTIPLY, 0, m, &cBinop_WqaAgiRq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vRl5spfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MgsHE6lY_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MgsHE6lY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QrrW53ov_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WqaAgiRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_tbE9jSmq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k5hcO0AV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WqaAgiRq, HV_BINOP_MULTIPLY, 1, m, &cBinop_WqaAgiRq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QrrW53ov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_k5hcO0AV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tbE9jSmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_NTQ31xab_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NTQ31xab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SfB8PKRG_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YmmNyNCI, m);
}

void Heavy_WSTD_DL3Y::cBinop_SfB8PKRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9LIrRBnH, m);
}

void Heavy_WSTD_DL3Y::cMsg_cNNItFOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ngTmFQ1B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ngTmFQ1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3cyfyuTo, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_M80OJOZN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lcYNPn7i, 0, m, &cSlice_lcYNPn7i_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4Aypk6mc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_lcYNPn7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mh0qTdg0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mh0qTdg0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_QQIHBXKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mh0qTdg0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_mh0qTdg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R21RMirD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_vpRsQkb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BxZzgYoM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_BxZzgYoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wiJBgzC9_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Wb5yHw4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Wb5yHw4m, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_E0FmBgyQ, 0, m, &cDelay_E0FmBgyQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Wb5yHw4m, 0, m, &cDelay_Wb5yHw4m_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_IZSaLWyz, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_E0FmBgyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_E0FmBgyQ, m);
  cMsg_apMlDpkx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_hqDuP6kg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_bw1l6eJN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_MZCoB4jZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nVdh42Iu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_Nqxc8Gqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cbhu18hN_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Wb5yHw4m, 2, m, &cDelay_Wb5yHw4m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gqy6rxAN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nVdh42Iu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Nqxc8Gqx, 0, m, &hTable_Nqxc8Gqx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wiJBgzC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_MZCoB4jZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_apMlDpkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Nqxc8Gqx, 0, m, &hTable_Nqxc8Gqx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Gqy6rxAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Wb5yHw4m, 0, m, &cDelay_Wb5yHw4m_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cbhu18hN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_E0FmBgyQ, 2, m, &cDelay_E0FmBgyQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bw1l6eJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_IZSaLWyz, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_OILW3jfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RKWFvCwn, HV_BINOP_SUBTRACT, 0, m, &cBinop_RKWFvCwn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hVMmfBPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QMcr0NV2_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_QMcr0NV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_SI8ELw2L_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_WOcUptEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4odTWz7m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_9Fwkykqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9Fwkykqz, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2BYFmaod, 0, m, &cDelay_2BYFmaod_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_88P4l8N4, 0, m, &sTabread_88P4l8N4_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_2BYFmaod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2BYFmaod, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_88P4l8N4, 0, m, &sTabread_88P4l8N4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2BYFmaod, 0, m, &cDelay_2BYFmaod_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_88P4l8N4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Z2JCPyD1, HV_BINOP_SUBTRACT, 0, m, &cBinop_Z2JCPyD1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_C0mt2yMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qejQTxiZ, HV_BINOP_MAX, 0, m, &cBinop_qejQTxiZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SI8ELw2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C0mt2yMt, HV_BINOP_MULTIPLY, 0, m, &cBinop_C0mt2yMt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RKWFvCwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rSBmvklU_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_88P4l8N4, 0, m, &sTabread_88P4l8N4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BncRoQHt_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_iPDpAETT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z2JCPyD1, HV_BINOP_SUBTRACT, 1, m, &cBinop_Z2JCPyD1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2BYFmaod, 2, m, &cDelay_2BYFmaod_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4odTWz7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iPDpAETT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rSBmvklU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9Fwkykqz, 0, m, &cDelay_9Fwkykqz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2BYFmaod, 0, m, &cDelay_2BYFmaod_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cP7CH3sH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_qejQTxiZ, HV_BINOP_MAX, 1, m, &cBinop_qejQTxiZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qejQTxiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RKWFvCwn, HV_BINOP_SUBTRACT, 1, m, &cBinop_RKWFvCwn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BncRoQHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9Fwkykqz, 0, m, &cDelay_9Fwkykqz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0Ax9hoqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9Fwkykqz, 2, m, &cDelay_9Fwkykqz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z2JCPyD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0Ax9hoqh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_30iX2m4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WOcUptEj, 0, m, &cVar_WOcUptEj_sendMessage);
  cMsg_hVMmfBPG_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OILW3jfW, 0, m, &cTabhead_OILW3jfW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fUhKKHE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oiYxdprQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_oiYxdprQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_CTsgbmkl_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_JlsK62wP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JlsK62wP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mWrsbVV9, 0, m, &cDelay_mWrsbVV9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JlsK62wP, 0, m, &cDelay_JlsK62wP_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_DAZh7ws1, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_mWrsbVV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mWrsbVV9, m);
  cMsg_rbgqxsfv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Ih4r3CYa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Cph0KsxS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_BOsbnoO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yeFxLtS1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_VFBC1AYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V13sgC4v_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JlsK62wP, 2, m, &cDelay_JlsK62wP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xFrlYFPj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yeFxLtS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_VFBC1AYT, 0, m, &hTable_VFBC1AYT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CTsgbmkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_BOsbnoO1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rbgqxsfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_VFBC1AYT, 0, m, &hTable_VFBC1AYT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xFrlYFPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JlsK62wP, 0, m, &cDelay_JlsK62wP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_V13sgC4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_mWrsbVV9, 2, m, &cDelay_mWrsbVV9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Cph0KsxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_DAZh7ws1, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_4As2gGAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AIFV1eNy, HV_BINOP_SUBTRACT, 0, m, &cBinop_AIFV1eNy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_W5IwNwtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gyVqJVT6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_gyVqJVT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7qXV8Aev_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_3pRlu4QV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dO64RjB8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_Aa6T5DF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Aa6T5DF4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CjkPy318, 0, m, &cDelay_CjkPy318_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_9fuDOVFz, 0, m, &sTabread_9fuDOVFz_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_CjkPy318_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CjkPy318, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_9fuDOVFz, 0, m, &sTabread_9fuDOVFz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CjkPy318, 0, m, &cDelay_CjkPy318_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_9fuDOVFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_GQ4OscfF, HV_BINOP_SUBTRACT, 0, m, &cBinop_GQ4OscfF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_vZ3VPjsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OAkCJXrW, HV_BINOP_MAX, 0, m, &cBinop_OAkCJXrW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7qXV8Aev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vZ3VPjsv, HV_BINOP_MULTIPLY, 0, m, &cBinop_vZ3VPjsv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AIFV1eNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UFKLLTkr_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_9fuDOVFz, 0, m, &sTabread_9fuDOVFz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J6wvkvSX_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_9lJD3hUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQ4OscfF, HV_BINOP_SUBTRACT, 1, m, &cBinop_GQ4OscfF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CjkPy318, 2, m, &cDelay_CjkPy318_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dO64RjB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9lJD3hUS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UFKLLTkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Aa6T5DF4, 0, m, &cDelay_Aa6T5DF4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CjkPy318, 0, m, &cDelay_CjkPy318_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6eWw9er2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_OAkCJXrW, HV_BINOP_MAX, 1, m, &cBinop_OAkCJXrW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OAkCJXrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AIFV1eNy, HV_BINOP_SUBTRACT, 1, m, &cBinop_AIFV1eNy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_J6wvkvSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Aa6T5DF4, 0, m, &cDelay_Aa6T5DF4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ySuNlXjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Aa6T5DF4, 2, m, &cDelay_Aa6T5DF4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GQ4OscfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ySuNlXjD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8WUVTh27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3pRlu4QV, 0, m, &cVar_3pRlu4QV_sendMessage);
  cMsg_W5IwNwtd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_4As2gGAg, 0, m, &cTabhead_4As2gGAg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BYOfG1zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EKWHcDK0, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_u0680Fvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gX3smx94, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_EK6vi0gZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WUhCUCVK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_emICJgGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WBSmVDMx, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5APFBY1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0tHkpsEL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_MuXGjkBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EnmN5MUc, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_afE5NXZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g7HO80IZ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_jdFAUTFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_latT5FNF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_lEs2q1Ex_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Lpj3vcBN, 0, m, &cSlice_Lpj3vcBN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Lpj3vcBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MqKwiLE7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MqKwiLE7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_hK4UzVdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MqKwiLE7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_MqKwiLE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0aI3Hqoq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_XYrC8jOn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_S1kxZwp3, 0, m, &cSlice_S1kxZwp3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NIJkE618_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_S1kxZwp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Z5JAqk2Z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Z5JAqk2Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_iELx3gHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Z5JAqk2Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Z5JAqk2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nT7jiRgU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_CjEkEFtA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FKkcsOsr, 0, m, &cSlice_FKkcsOsr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lEs2q1Ex_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_FKkcsOsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mOFVnPWW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mOFVnPWW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_zIxzuxHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mOFVnPWW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_mOFVnPWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_X0yXp7gF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_q4qML1yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xwjnTi7E_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xwjnTi7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_OQfhxxPW_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_aViglVWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XvSh95ly_sendMessage(_c, 0, m);
  cMsg_kRfiE1sm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_qa3ini9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vTHffJyd_sendMessage(_c, 0, m);
  cMsg_NlAnA5W9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OQfhxxPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pL6AoHpv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pL6AoHpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XVtSCEvO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_15Urf4XF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_15Urf4XF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_egBRhhW6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XVtSCEvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yCWMCCmB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yCWMCCmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WKDewt7M_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_egBRhhW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ave66chs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ave66chs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_db89zqW8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WKDewt7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_aViglVWo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_db89zqW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_qa3ini9a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_puSTArsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fmlAZAmk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fmlAZAmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_AoZkwjaY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AoZkwjaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qO86AcUe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qO86AcUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X1rjdJR8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V8yvBKYz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_V8yvBKYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tmUoJNFE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_X1rjdJR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YG8AXB6X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YG8AXB6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lLSFU1N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tmUoJNFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_c0fGOnmi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c0fGOnmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5HtSo8J2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5HtSo8J2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tUzWM7K7_sendMessage(_c, 0, m);
  cMsg_uJrDBl65_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lLSFU1N8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I6WxfTKi_sendMessage(_c, 0, m);
  cMsg_27G1yFRW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vq1g6jXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_a7Yru2A2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a7Yru2A2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ls4R8XZW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lTCWAA57_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_VzagbFsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_dTuUzCLI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cwq46Lvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6nBpa1Z9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_6nBpa1Z9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AFq1wGAE, HV_BINOP_DIVIDE, 1, m, &cBinop_AFq1wGAE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ls4R8XZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mFM35i1x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mFM35i1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_1NBiUugJ, m);
}

void Heavy_WSTD_DL3Y::cMsg_G4wqpWjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_h95ACvmG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_h95ACvmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vq1g6jXC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lTCWAA57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_1hgTVPUz, m);
}

void Heavy_WSTD_DL3Y::cBinop_dTuUzCLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_zt4Mj8c9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zt4Mj8c9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AFq1wGAE, HV_BINOP_DIVIDE, 0, m, &cBinop_AFq1wGAE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AFq1wGAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G4wqpWjA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AVMU07ax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_UeehGIFc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UeehGIFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4UX7Nbex_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vicn1XBg_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_rQr2U2ia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_vnNHwBrg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5YrOk96A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yJBaVC5v_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_yJBaVC5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5vE3q61u, HV_BINOP_DIVIDE, 1, m, &cBinop_5vE3q61u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4UX7Nbex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FTS419M4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FTS419M4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Fl03eEjh, m);
}

void Heavy_WSTD_DL3Y::cMsg_Jnzqc5DO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1E2YHW97_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1E2YHW97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_AVMU07ax_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vicn1XBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_stJtppda, m);
}

void Heavy_WSTD_DL3Y::cBinop_vnNHwBrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_ukff3CDm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ukff3CDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5vE3q61u, HV_BINOP_DIVIDE, 0, m, &cBinop_5vE3q61u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5vE3q61u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jnzqc5DO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_RIAQtnQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PQC7C6M4, HV_BINOP_MULTIPLY, 0, m, &cBinop_PQC7C6M4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RgWmG7M6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WLALuqgu_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_WLALuqgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6TKfmOYa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PQC7C6M4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Db3mFLVk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IXZsGHBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PQC7C6M4, HV_BINOP_MULTIPLY, 1, m, &cBinop_PQC7C6M4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6TKfmOYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IXZsGHBo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Db3mFLVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_sL8yf9K5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sL8yf9K5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xEgxFm5m_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_AooqllU8, m);
}

void Heavy_WSTD_DL3Y::cBinop_xEgxFm5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0WVJXuXU, m);
}

void Heavy_WSTD_DL3Y::cVar_SxTaV1ZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_re19H5Gg, HV_BINOP_MULTIPLY, 0, m, &cBinop_re19H5Gg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sGBNXPeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YgSEJvMj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_YgSEJvMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ie4yKUzH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_re19H5Gg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_9DcwVYkK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wygBQPg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_re19H5Gg, HV_BINOP_MULTIPLY, 1, m, &cBinop_re19H5Gg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ie4yKUzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wygBQPg3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9DcwVYkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6jnJTvUp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6jnJTvUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Sg0iHjga_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WkugDomD, m);
}

void Heavy_WSTD_DL3Y::cBinop_Sg0iHjga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_w6VxHtNH, m);
}

void Heavy_WSTD_DL3Y::sEnv_FmRRQinS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YXs8Dh5R_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k1ahtIWe_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_4hMAEae9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_FPSs6aRG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_jzsu6agE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_fSsgAP67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1kCoJYv4, HV_BINOP_POW, 0, m, &cBinop_1kCoJYv4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1kCoJYv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_09EfWJkX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FLmFhg2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_iXZIyQ5o_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YXs8Dh5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MndfEOiZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_k1ahtIWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4hMAEae9, 0, m, &cIf_4hMAEae9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MndfEOiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4hMAEae9, 1, m, &cIf_4hMAEae9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jzsu6agE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_FLmFhg2B_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FPSs6aRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_09EfWJkX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iXZIyQ5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1kCoJYv4, HV_BINOP_POW, 1, m, &cBinop_1kCoJYv4_sendMessage);
  cMsg_fSsgAP67_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_H6rbuXRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VxMnWvs5, HV_BINOP_MULTIPLY, 0, m, &cBinop_VxMnWvs5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Rs4U4NpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UUoB4Xyg_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_UUoB4Xyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_45dWiiQ7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VxMnWvs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_IHrzOGDi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8wsWVpgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VxMnWvs5, HV_BINOP_MULTIPLY, 1, m, &cBinop_VxMnWvs5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_45dWiiQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8wsWVpgo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IHrzOGDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_3rAolDMg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3rAolDMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_s75ltmTl_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_kJes2FXU, m);
}

void Heavy_WSTD_DL3Y::cBinop_s75ltmTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7QwyWToa, m);
}

void Heavy_WSTD_DL3Y::cMsg_09EfWJkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fKamgAEc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fKamgAEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CBudM7Zj, m);
}

void Heavy_WSTD_DL3Y::sEnv_VMyB4ERs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QqIBt4TV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F5Oc122G_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_DqhRPJXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_UjAudGkO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_xStAPq2o_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_M5sCKHm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uJWGEZA7, HV_BINOP_POW, 0, m, &cBinop_uJWGEZA7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uJWGEZA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vddoRL9f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_uAcEOCHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_PW8AGD51_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F5Oc122G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DqhRPJXm, 0, m, &cIf_DqhRPJXm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QqIBt4TV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_6FdrmGMc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6FdrmGMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DqhRPJXm, 1, m, &cIf_DqhRPJXm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xStAPq2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_uAcEOCHX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UjAudGkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_vddoRL9f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PW8AGD51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uJWGEZA7, HV_BINOP_POW, 1, m, &cBinop_uJWGEZA7_sendMessage);
  cMsg_M5sCKHm6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_1Qw0GnSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OdguaKst, HV_BINOP_MULTIPLY, 0, m, &cBinop_OdguaKst_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3jrn0ElH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vMbnvb93_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_vMbnvb93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g5ECH8x9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OdguaKst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1bduZqXA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a12xXINx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OdguaKst, HV_BINOP_MULTIPLY, 1, m, &cBinop_OdguaKst_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_g5ECH8x9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_a12xXINx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1bduZqXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_aCG6SDVa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aCG6SDVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_b5IT0Yre_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_AQPWyglo, m);
}

void Heavy_WSTD_DL3Y::cBinop_b5IT0Yre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MC4i5IEe, m);
}

void Heavy_WSTD_DL3Y::cMsg_vddoRL9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Qjx2HAje_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qjx2HAje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mtXgrCU9, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_NIJkE618_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WVxxR57k, 0, m, &cSlice_WVxxR57k_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CjEkEFtA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_WVxxR57k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QhGVhsnr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QhGVhsnr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_PJHOhvaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QhGVhsnr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_QhGVhsnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qDFH7X29_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_SYiCLT5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DFiq1i0Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_DFiq1i0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NSNclwcq_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_2fJfaeeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2fJfaeeJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jJ9GwMTL, 0, m, &cDelay_jJ9GwMTL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2fJfaeeJ, 0, m, &cDelay_2fJfaeeJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YNhQVaMz, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_jJ9GwMTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jJ9GwMTL, m);
  cMsg_lykI8fPY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_PsXPf2bm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_W7cyaPav_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_V7VJTnhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GAP1HoRG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_bkrY9PzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_agnsOjsz_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2fJfaeeJ, 2, m, &cDelay_2fJfaeeJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pDQFgJ5l_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GAP1HoRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_bkrY9PzY, 0, m, &hTable_bkrY9PzY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NSNclwcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_V7VJTnhj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lykI8fPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_bkrY9PzY, 0, m, &hTable_bkrY9PzY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pDQFgJ5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2fJfaeeJ, 0, m, &cDelay_2fJfaeeJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_agnsOjsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_jJ9GwMTL, 2, m, &cDelay_jJ9GwMTL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_W7cyaPav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YNhQVaMz, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_CWfluwZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2vGwMD56, HV_BINOP_SUBTRACT, 0, m, &cBinop_2vGwMD56_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_28p8iRuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IgDENKdB_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_IgDENKdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_t7WHDK2B_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_9SK4VCUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sbS4lTYG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_e1iilHtj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_e1iilHtj, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QzYdKHmI, 0, m, &cDelay_QzYdKHmI_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_tEe7T59t, 0, m, &sTabread_tEe7T59t_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_QzYdKHmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QzYdKHmI, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_tEe7T59t, 0, m, &sTabread_tEe7T59t_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QzYdKHmI, 0, m, &cDelay_QzYdKHmI_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_tEe7T59t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_UlUXnhSh, HV_BINOP_SUBTRACT, 0, m, &cBinop_UlUXnhSh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_Z0MjBnfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WuZLbOgQ, HV_BINOP_MAX, 0, m, &cBinop_WuZLbOgQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t7WHDK2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z0MjBnfJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z0MjBnfJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2vGwMD56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F8F2De60_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_tEe7T59t, 0, m, &sTabread_tEe7T59t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BlBOiIc3_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_yvp6mgHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UlUXnhSh, HV_BINOP_SUBTRACT, 1, m, &cBinop_UlUXnhSh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QzYdKHmI, 2, m, &cDelay_QzYdKHmI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sbS4lTYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yvp6mgHK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_F8F2De60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_e1iilHtj, 0, m, &cDelay_e1iilHtj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QzYdKHmI, 0, m, &cDelay_QzYdKHmI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ThTz0BjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_WuZLbOgQ, HV_BINOP_MAX, 1, m, &cBinop_WuZLbOgQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WuZLbOgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2vGwMD56, HV_BINOP_SUBTRACT, 1, m, &cBinop_2vGwMD56_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BlBOiIc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_e1iilHtj, 0, m, &cDelay_e1iilHtj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rhEVixYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_e1iilHtj, 2, m, &cDelay_e1iilHtj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UlUXnhSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rhEVixYK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nQut9rpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9SK4VCUg, 0, m, &cVar_9SK4VCUg_sendMessage);
  cMsg_28p8iRuA_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_CWfluwZY, 0, m, &cTabhead_CWfluwZY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EowopJqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_khG9AYDF_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_khG9AYDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gpGBcmSK_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_IFYHyEpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IFYHyEpo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_y7W4yyBX, 0, m, &cDelay_y7W4yyBX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IFYHyEpo, 0, m, &cDelay_IFYHyEpo_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_U0lQgC0L, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_y7W4yyBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_y7W4yyBX, m);
  cMsg_YubwYpsa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_fiE8j3dN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_n2oQK6ZA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_d2L4WOsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9mEMY0rL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_CLjbKCjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wl5F5gkN_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IFYHyEpo, 2, m, &cDelay_IFYHyEpo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sd03yCGu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9mEMY0rL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_CLjbKCjX, 0, m, &hTable_CLjbKCjX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gpGBcmSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_d2L4WOsu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YubwYpsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_CLjbKCjX, 0, m, &hTable_CLjbKCjX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sd03yCGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IFYHyEpo, 0, m, &cDelay_IFYHyEpo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Wl5F5gkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_y7W4yyBX, 2, m, &cDelay_y7W4yyBX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_n2oQK6ZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_U0lQgC0L, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_EAFgGpid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PL8PaLVY, HV_BINOP_SUBTRACT, 0, m, &cBinop_PL8PaLVY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Tk5xSNQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HCeGPCX2_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_HCeGPCX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Lpjnpd5J_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_NN8KfqgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xq0lTLYX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_4l7pN7hw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4l7pN7hw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8VdUPWF4, 0, m, &cDelay_8VdUPWF4_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_JBbdrubd, 0, m, &sTabread_JBbdrubd_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_8VdUPWF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8VdUPWF4, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_JBbdrubd, 0, m, &sTabread_JBbdrubd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8VdUPWF4, 0, m, &cDelay_8VdUPWF4_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_JBbdrubd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_rxTLSSJG, HV_BINOP_SUBTRACT, 0, m, &cBinop_rxTLSSJG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_e5Ry4GUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4b41nFF3, HV_BINOP_MAX, 0, m, &cBinop_4b41nFF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lpjnpd5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e5Ry4GUx, HV_BINOP_MULTIPLY, 0, m, &cBinop_e5Ry4GUx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PL8PaLVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BMd19Uul_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_JBbdrubd, 0, m, &sTabread_JBbdrubd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_muxlZb2J_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_veqbW8Oi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rxTLSSJG, HV_BINOP_SUBTRACT, 1, m, &cBinop_rxTLSSJG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8VdUPWF4, 2, m, &cDelay_8VdUPWF4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xq0lTLYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_veqbW8Oi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BMd19Uul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4l7pN7hw, 0, m, &cDelay_4l7pN7hw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8VdUPWF4, 0, m, &cDelay_8VdUPWF4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ltvPfxaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_4b41nFF3, HV_BINOP_MAX, 1, m, &cBinop_4b41nFF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4b41nFF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PL8PaLVY, HV_BINOP_SUBTRACT, 1, m, &cBinop_PL8PaLVY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_muxlZb2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4l7pN7hw, 0, m, &cDelay_4l7pN7hw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_koh20YMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4l7pN7hw, 2, m, &cDelay_4l7pN7hw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rxTLSSJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_koh20YMh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2yJvQhRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NN8KfqgD, 0, m, &cVar_NN8KfqgD_sendMessage);
  cMsg_Tk5xSNQp_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_EAFgGpid, 0, m, &cTabhead_EAFgGpid_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XvSh95ly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qXFagoE8, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vTHffJyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DBGJo0M6, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NlAnA5W9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_szICNOzI, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kRfiE1sm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yS8mLSqf, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_27G1yFRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7YEMQ66A, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tUzWM7K7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RTCmVshi, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_I6WxfTKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CHRiuvds, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uJrDBl65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IlN73JKL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_5hP7P5mr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EP5LahlA, 0, m, &cSlice_EP5LahlA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_EP5LahlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vXe0JxBc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vXe0JxBc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_NEyD8hyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vXe0JxBc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_vXe0JxBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ibfo7HYl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_i8m3ivvv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_z5igXM8L, 0, m, &cSlice_z5igXM8L_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uzLKAdyK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_z5igXM8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_D0Qqjwxb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_D0Qqjwxb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_mSPmdp2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_D0Qqjwxb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_D0Qqjwxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oIF66tto_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Y1kWEEoH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ns0TI7KA, 0, m, &cSlice_Ns0TI7KA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5hP7P5mr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Ns0TI7KA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jY6g32Lr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jY6g32Lr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_RhIqKyIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jY6g32Lr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_jY6g32Lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ba5FQief_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Shs3PeTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MXovdzgy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MXovdzgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_bqBMywZS_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_GqG8UImD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a2s7W5WX_sendMessage(_c, 0, m);
  cMsg_Zspk47em_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_3mq8nNRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1O7j41v5_sendMessage(_c, 0, m);
  cMsg_FyY2P1SI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bqBMywZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pferKzzc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pferKzzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1y7IbH68_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zJNGBqiu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zJNGBqiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XgOHJPdb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_1y7IbH68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9DFM4qxp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9DFM4qxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IICl5tIg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XgOHJPdb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_h5j2CRQb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_h5j2CRQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_exvFXJA1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IICl5tIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_GqG8UImD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_exvFXJA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_3mq8nNRA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nncJtpMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rYvB5zU1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rYvB5zU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ktIFFqyT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ktIFFqyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_dLLaPfUA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dLLaPfUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DUIlycE3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d1RcESSU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_d1RcESSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eDKxzGy2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_DUIlycE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nmbiqFK3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nmbiqFK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sDsKwlzo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eDKxzGy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_09s21m1o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_09s21m1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1nQGaAV3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1nQGaAV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_65oTyoxt_sendMessage(_c, 0, m);
  cMsg_LE2KkoTH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_sDsKwlzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rATH6Cy2_sendMessage(_c, 0, m);
  cMsg_JDVhueeQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QhjbQ6tN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_aOHNmV3p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aOHNmV3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rjhRGqjR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_43vnuFck_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_RHtcTtEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_L5WR8xSn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tTserdJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tMTm4W5W_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_tMTm4W5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rRWD1HPq, HV_BINOP_DIVIDE, 1, m, &cBinop_rRWD1HPq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rjhRGqjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iG5Psq2x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iG5Psq2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qiCoBg3U, m);
}

void Heavy_WSTD_DL3Y::cMsg_P5mbltAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_E8L66Jmj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_E8L66Jmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QhjbQ6tN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_43vnuFck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GRHbp2Gr, m);
}

void Heavy_WSTD_DL3Y::cBinop_L5WR8xSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_qgoiJfy7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qgoiJfy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rRWD1HPq, HV_BINOP_DIVIDE, 0, m, &cBinop_rRWD1HPq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rRWD1HPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P5mbltAn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DEQt3iFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_nHp17Pno_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nHp17Pno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OrFdlnIo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LnfNURkx_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_5ExCfMeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_0NcYOW7p_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JJgbpN6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dGFpfUvV_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_dGFpfUvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GUbdfTCh, HV_BINOP_DIVIDE, 1, m, &cBinop_GUbdfTCh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OrFdlnIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EiyZKJnd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EiyZKJnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mPM7CMKo, m);
}

void Heavy_WSTD_DL3Y::cMsg_utlrZo2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iilM0Zod_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iilM0Zod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_DEQt3iFx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LnfNURkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_h9QdCowF, m);
}

void Heavy_WSTD_DL3Y::cBinop_0NcYOW7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_VNwX6VeF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VNwX6VeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GUbdfTCh, HV_BINOP_DIVIDE, 0, m, &cBinop_GUbdfTCh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GUbdfTCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_utlrZo2I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_nmZyejLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KJ2vG8uL, HV_BINOP_MULTIPLY, 0, m, &cBinop_KJ2vG8uL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hiphU4VR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ehBHSd6c_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ehBHSd6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2GavgFu6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KJ2vG8uL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_m9q2LVay_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I3FTiVL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KJ2vG8uL, HV_BINOP_MULTIPLY, 1, m, &cBinop_KJ2vG8uL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2GavgFu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_I3FTiVL4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_m9q2LVay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_k1qQIQag_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k1qQIQag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Iqtih9DC_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fkS7dNPe, m);
}

void Heavy_WSTD_DL3Y::cBinop_Iqtih9DC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_J6FEfXyu, m);
}

void Heavy_WSTD_DL3Y::cVar_zRZl5bw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mnLW18g3, HV_BINOP_MULTIPLY, 0, m, &cBinop_mnLW18g3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_stQv3IXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_L4zLpPi2_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_L4zLpPi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_svfpoP4y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mnLW18g3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_dX9AJjvm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8anc9dWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mnLW18g3, HV_BINOP_MULTIPLY, 1, m, &cBinop_mnLW18g3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_svfpoP4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8anc9dWY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dX9AJjvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4aHYsXbE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4aHYsXbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VZVcum9k_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_l6KOArSv, m);
}

void Heavy_WSTD_DL3Y::cBinop_VZVcum9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_K1RdOUoV, m);
}

void Heavy_WSTD_DL3Y::sEnv_cdB17ugT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CSJjLw2m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xpcO5AAU_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_WuPSM8Eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_J4mD0cd2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_9AuyJjzA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_2bIOV0VE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ulRS0lAm, HV_BINOP_POW, 0, m, &cBinop_ulRS0lAm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ulRS0lAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FQEURUor_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_wU7SqUcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_nAOk7fjY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xpcO5AAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WuPSM8Eg, 0, m, &cIf_WuPSM8Eg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CSJjLw2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NkFmlhyt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NkFmlhyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WuPSM8Eg, 1, m, &cIf_WuPSM8Eg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9AuyJjzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_wU7SqUcU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_J4mD0cd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_FQEURUor_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nAOk7fjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ulRS0lAm, HV_BINOP_POW, 1, m, &cBinop_ulRS0lAm_sendMessage);
  cMsg_2bIOV0VE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_3SpvmZij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yNOqKmtR, HV_BINOP_MULTIPLY, 0, m, &cBinop_yNOqKmtR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lsMkuOJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7cpnLCIB_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7cpnLCIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_24cedLwH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_yNOqKmtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vA02WXeQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WDY8K6B2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yNOqKmtR, HV_BINOP_MULTIPLY, 1, m, &cBinop_yNOqKmtR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_24cedLwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WDY8K6B2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vA02WXeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_b2tYUsHY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b2tYUsHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_sx3dU2BM_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_2RLt09RX, m);
}

void Heavy_WSTD_DL3Y::cBinop_sx3dU2BM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Cyp4TkbL, m);
}

void Heavy_WSTD_DL3Y::cMsg_FQEURUor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uJloQzS1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uJloQzS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8rmWgXZf, m);
}

void Heavy_WSTD_DL3Y::sEnv_GweqS9hl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MraNZL2g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JO0kXciD_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_tMwBAxf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_zzLgMkc9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ryTQbxGt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_LZcm93Ts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Li7K8xdr, HV_BINOP_POW, 0, m, &cBinop_Li7K8xdr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Li7K8xdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_As4h04MQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SEBeZtg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_2uNsprYd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JO0kXciD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tMwBAxf5, 0, m, &cIf_tMwBAxf5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MraNZL2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZkbjOwhd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZkbjOwhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tMwBAxf5, 1, m, &cIf_tMwBAxf5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ryTQbxGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_SEBeZtg6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zzLgMkc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_As4h04MQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2uNsprYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Li7K8xdr, HV_BINOP_POW, 1, m, &cBinop_Li7K8xdr_sendMessage);
  cMsg_LZcm93Ts_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Tnlhgbz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1rgTcZcH, HV_BINOP_MULTIPLY, 0, m, &cBinop_1rgTcZcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_05QyZOvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_X7HxmqLf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_X7HxmqLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z2fugRBb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1rgTcZcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_P6tifhau_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bIKnR8oq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1rgTcZcH, HV_BINOP_MULTIPLY, 1, m, &cBinop_1rgTcZcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Z2fugRBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bIKnR8oq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P6tifhau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Pps5Qwyy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pps5Qwyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zoekFtnb_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LeXb1Czs, m);
}

void Heavy_WSTD_DL3Y::cBinop_zoekFtnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Kas2Ya6A, m);
}

void Heavy_WSTD_DL3Y::cMsg_As4h04MQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tk9ypkjY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tk9ypkjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cHxVmFla, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_uzLKAdyK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mZPumJNZ, 0, m, &cSlice_mZPumJNZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Y1kWEEoH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_mZPumJNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VQQbR7p2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VQQbR7p2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_GxC6LnUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VQQbR7p2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_VQQbR7p2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bHfDdR65_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_CU4ivoFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ToqEESvY_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ToqEESvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_eUcyz7rF_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Uh9qACET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Uh9qACET, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jZBp2FRE, 0, m, &cDelay_jZBp2FRE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Uh9qACET, 0, m, &cDelay_Uh9qACET_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_d5YAn1r5, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_jZBp2FRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jZBp2FRE, m);
  cMsg_pjL84oFf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_9JCUL5CW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_dwwF1oMl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_BIWcFwTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eSW1yi9W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_Km1SNKyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x7xeYKK8_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Uh9qACET, 2, m, &cDelay_Uh9qACET_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Ep865zd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eSW1yi9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Km1SNKyV, 0, m, &hTable_Km1SNKyV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eUcyz7rF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_BIWcFwTy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pjL84oFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Km1SNKyV, 0, m, &hTable_Km1SNKyV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3Ep865zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Uh9qACET, 0, m, &cDelay_Uh9qACET_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_x7xeYKK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_jZBp2FRE, 2, m, &cDelay_jZBp2FRE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dwwF1oMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_d5YAn1r5, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_rtNHs1pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YbOJSzPT, HV_BINOP_SUBTRACT, 0, m, &cBinop_YbOJSzPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2fTog3mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_khKsyh1D_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_khKsyh1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_MasgTMOX_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_uxtrqjdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_inalvRND_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_BX0lrHSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BX0lrHSf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BDSPCWvr, 0, m, &cDelay_BDSPCWvr_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EQCjqBiZ, 0, m, &sTabread_EQCjqBiZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_BDSPCWvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BDSPCWvr, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EQCjqBiZ, 0, m, &sTabread_EQCjqBiZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BDSPCWvr, 0, m, &cDelay_BDSPCWvr_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_EQCjqBiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yf1i14Ax, HV_BINOP_SUBTRACT, 0, m, &cBinop_yf1i14Ax_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_q43KK0WV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uArtq3hF, HV_BINOP_MAX, 0, m, &cBinop_uArtq3hF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MasgTMOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q43KK0WV, HV_BINOP_MULTIPLY, 0, m, &cBinop_q43KK0WV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YbOJSzPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SI3cNzfu_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EQCjqBiZ, 0, m, &sTabread_EQCjqBiZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RSwJ5QIY_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Cja84YlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yf1i14Ax, HV_BINOP_SUBTRACT, 1, m, &cBinop_yf1i14Ax_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BDSPCWvr, 2, m, &cDelay_BDSPCWvr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_inalvRND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Cja84YlP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SI3cNzfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BX0lrHSf, 0, m, &cDelay_BX0lrHSf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BDSPCWvr, 0, m, &cDelay_BDSPCWvr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0p0k0Pyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_uArtq3hF, HV_BINOP_MAX, 1, m, &cBinop_uArtq3hF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uArtq3hF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YbOJSzPT, HV_BINOP_SUBTRACT, 1, m, &cBinop_YbOJSzPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RSwJ5QIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BX0lrHSf, 0, m, &cDelay_BX0lrHSf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DRdsBN4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BX0lrHSf, 2, m, &cDelay_BX0lrHSf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yf1i14Ax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DRdsBN4V_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sPmtJw7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uxtrqjdW, 0, m, &cVar_uxtrqjdW_sendMessage);
  cMsg_2fTog3mb_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_rtNHs1pf, 0, m, &cTabhead_rtNHs1pf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kOgjoa2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3rEAcmAf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_3rEAcmAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cy5A6gyZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_dEsIw7WI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dEsIw7WI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tBmGRjcA, 0, m, &cDelay_tBmGRjcA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dEsIw7WI, 0, m, &cDelay_dEsIw7WI_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_InYlpA9W, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_tBmGRjcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tBmGRjcA, m);
  cMsg_FIlFV6dI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_oo3ueoKq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_VjCjBIYg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_rGEMVjPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5r0oTO4H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_rzixzLEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BIJiQjMY_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dEsIw7WI, 2, m, &cDelay_dEsIw7WI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tC3kwZoP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5r0oTO4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_rzixzLEt, 0, m, &hTable_rzixzLEt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cy5A6gyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_rGEMVjPG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FIlFV6dI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_rzixzLEt, 0, m, &hTable_rzixzLEt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tC3kwZoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dEsIw7WI, 0, m, &cDelay_dEsIw7WI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BIJiQjMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_tBmGRjcA, 2, m, &cDelay_tBmGRjcA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VjCjBIYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_InYlpA9W, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_TUqyUSSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zl4Cr4dK, HV_BINOP_SUBTRACT, 0, m, &cBinop_zl4Cr4dK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lFD1r0pP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MMDGpSPS_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MMDGpSPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5wIRLwvC_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_9MtLESzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K6Yc12fw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_AagDrF5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AagDrF5v, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qwKxzDUW, 0, m, &cDelay_qwKxzDUW_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ghk2qPiE, 0, m, &sTabread_Ghk2qPiE_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_qwKxzDUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qwKxzDUW, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ghk2qPiE, 0, m, &sTabread_Ghk2qPiE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qwKxzDUW, 0, m, &cDelay_qwKxzDUW_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_Ghk2qPiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_CqNcb01J, HV_BINOP_SUBTRACT, 0, m, &cBinop_CqNcb01J_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_bdnvktuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9WLhGPIT, HV_BINOP_MAX, 0, m, &cBinop_9WLhGPIT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5wIRLwvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bdnvktuQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_bdnvktuQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zl4Cr4dK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MgSOW3Hr_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ghk2qPiE, 0, m, &sTabread_Ghk2qPiE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F6I4mlI3_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_wSAL07mU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CqNcb01J, HV_BINOP_SUBTRACT, 1, m, &cBinop_CqNcb01J_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qwKxzDUW, 2, m, &cDelay_qwKxzDUW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_K6Yc12fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wSAL07mU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MgSOW3Hr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AagDrF5v, 0, m, &cDelay_AagDrF5v_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qwKxzDUW, 0, m, &cDelay_qwKxzDUW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xhLrhfmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_9WLhGPIT, HV_BINOP_MAX, 1, m, &cBinop_9WLhGPIT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9WLhGPIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zl4Cr4dK, HV_BINOP_SUBTRACT, 1, m, &cBinop_zl4Cr4dK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F6I4mlI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AagDrF5v, 0, m, &cDelay_AagDrF5v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xV7i2Xye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AagDrF5v, 2, m, &cDelay_AagDrF5v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CqNcb01J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xV7i2Xye_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_62sb3EzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9MtLESzg, 0, m, &cVar_9MtLESzg_sendMessage);
  cMsg_lFD1r0pP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_TUqyUSSA, 0, m, &cTabhead_TUqyUSSA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_a2s7W5WX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VakqqU9H, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_1O7j41v5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HJqrgxnp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_FyY2P1SI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_svvfxEeX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Zspk47em_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OHFFT9xn, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JDVhueeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7hOZIiUh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_65oTyoxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QDv9EnMu, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_rATH6Cy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rVxW7bIZ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_LE2KkoTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DQcT6Jcw, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_fEstoHfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1pDFoBWu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iBXbrxpZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ptl2w7eZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1pDFoBWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fEstoHfQ, 1, m, &cVar_fEstoHfQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_IKLX05Wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ztHRwYth, 0, m, &cVar_ztHRwYth_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_YN12LwFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ztHRwYth, 0, m, &cVar_ztHRwYth_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_r3bNIcAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YN12LwFz, 0, m, &cIf_YN12LwFz_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FsKHr6XP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IKLX05Wa, 0, m, &cIf_IKLX05Wa_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_T4Glud5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_p0rgGJ6i_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5hAy6X6v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_L0YJfBG2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p0rgGJ6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T4Glud5H, 1, m, &cVar_T4Glud5H_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_7Ajh2rFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Rn46oavl, 0, m, &cVar_Rn46oavl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_0Nq3IXtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Rn46oavl, 0, m, &cVar_Rn46oavl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_7zAC2a44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0Nq3IXtG, 0, m, &cIf_0Nq3IXtG_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Da9sCEk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7Ajh2rFS, 0, m, &cIf_7Ajh2rFS_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_oevGClSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qIGj1gSC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1kRXYU3a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5sTEor4t_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qIGj1gSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oevGClSi, 1, m, &cVar_oevGClSi_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_RYtzLkZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_VHZl2OXc, 0, m, &cVar_VHZl2OXc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_aHVNALKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_VHZl2OXc, 0, m, &cVar_VHZl2OXc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_WA0SEQCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aHVNALKW, 0, m, &cIf_aHVNALKW_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_y4xo67uc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RYtzLkZK, 0, m, &cIf_RYtzLkZK_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mkCKsYfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_flfVqE0d, HV_BINOP_DIVIDE, 0, m, &cBinop_flfVqE0d_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_i5aewoiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zEHuWYNw, HV_BINOP_MULTIPLY, 1, m, &cBinop_zEHuWYNw_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_5Rah6XQU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_y36Bv1tR, 0, m, &cSlice_y36Bv1tR_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bwmyZBVS, 0, m, &cSlice_bwmyZBVS_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C40TjOaF_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9f32avE2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_y36Bv1tR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_CLhkITmU, 0, m, &cVar_CLhkITmU_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_CLhkITmU, 0, m, &cVar_CLhkITmU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_bwmyZBVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_K0gKBbV7, HV_BINOP_NEQ, 1, m, &cBinop_K0gKBbV7_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_CLhkITmU, 1, m, &cVar_CLhkITmU_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_K0gKBbV7, HV_BINOP_NEQ, 1, m, &cBinop_K0gKBbV7_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_CLhkITmU, 1, m, &cVar_CLhkITmU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_CLhkITmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_CJy7RW00_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_SUvr1fTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Egn1UsfN_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q9wXAnKw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_q9wXAnKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CLhkITmU, 0, m, &cVar_CLhkITmU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Egn1UsfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K0gKBbV7, HV_BINOP_NEQ, 1, m, &cBinop_K0gKBbV7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_K0gKBbV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SUvr1fTn, 1, m, &cIf_SUvr1fTn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9f32avE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SUvr1fTn, 0, m, &cIf_SUvr1fTn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C40TjOaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K0gKBbV7, HV_BINOP_NEQ, 0, m, &cBinop_K0gKBbV7_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_yE5SP7md_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G0lRqQIO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G4OjnYs1_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_gGFqgxaq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DAGwPGmJ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yZolXwC9_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FujbKLRC_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uD7blLEO_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8oQa57ZU_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RCBCOxpC_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QkyQ2Vla_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VxPibAhC_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4GhalVE3_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1uKN4G6P_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IU094vnI_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CqkJU8cp_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RfUCBjgc_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_DAGwPGmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DkMpx9ls_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_yZolXwC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TQO43bqJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_FujbKLRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QG4l66sc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uD7blLEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7WxxvBMS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_8oQa57ZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vyjf2KJt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_RCBCOxpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9MlRu34K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QkyQ2Vla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lmm9EWks_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_VxPibAhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FZpSQMJW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_4GhalVE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zGDjkWoi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_1uKN4G6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MPtE0Onm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_IU094vnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NlP2UktT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_CqkJU8cp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UXewYOiR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_RfUCBjgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1lYgEbkF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_flfVqE0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zEHuWYNw, HV_BINOP_MULTIPLY, 0, m, &cBinop_zEHuWYNw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zEHuWYNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5Rah6XQU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_G4OjnYs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mkCKsYfv, 0, m, &cVar_mkCKsYfv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_i5aewoiA, 0, m, &cVar_i5aewoiA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_G0lRqQIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_flfVqE0d, HV_BINOP_DIVIDE, 1, m, &cBinop_flfVqE0d_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qi45KonP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i5aewoiA, 0, m, &cVar_i5aewoiA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vcSKhaFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mkCKsYfv, 0, m, &cVar_mkCKsYfv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DkMpx9ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TQO43bqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QG4l66sc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7WxxvBMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vyjf2KJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9MlRu34K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Lmm9EWks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FZpSQMJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zGDjkWoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MPtE0Onm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NlP2UktT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UXewYOiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1lYgEbkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qi45KonP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcSKhaFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_5UsQDU2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fOiKQBmP, HV_BINOP_DIVIDE, 0, m, &cBinop_fOiKQBmP_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_gDxilEMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ki804htm, HV_BINOP_MULTIPLY, 1, m, &cBinop_ki804htm_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_mV95VbMG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DuH0tqqT, 0, m, &cSlice_DuH0tqqT_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4VMUGv4y, 0, m, &cSlice_4VMUGv4y_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fPLWmd0E_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_43e3V2T6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_DuH0tqqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_Yeg8bUCn, 0, m, &cVar_Yeg8bUCn_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Yeg8bUCn, 0, m, &cVar_Yeg8bUCn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_4VMUGv4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_w0YnjoKm, HV_BINOP_NEQ, 1, m, &cBinop_w0YnjoKm_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_Yeg8bUCn, 1, m, &cVar_Yeg8bUCn_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_w0YnjoKm, HV_BINOP_NEQ, 1, m, &cBinop_w0YnjoKm_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_Yeg8bUCn, 1, m, &cVar_Yeg8bUCn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Yeg8bUCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_S1uwJZQb_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_1575Y6FW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_icytnoBf_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fqska3KW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_Fqska3KW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Yeg8bUCn, 0, m, &cVar_Yeg8bUCn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_icytnoBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w0YnjoKm, HV_BINOP_NEQ, 1, m, &cBinop_w0YnjoKm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w0YnjoKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1575Y6FW, 1, m, &cIf_1575Y6FW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_43e3V2T6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1575Y6FW, 0, m, &cIf_1575Y6FW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fPLWmd0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w0YnjoKm, HV_BINOP_NEQ, 0, m, &cBinop_w0YnjoKm_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_LsaReSyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bAA6CP3j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lgaq3EZn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3oHroRfX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lcfWwY2a_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VJGjXq21_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qegNp8Za_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FPgdi6tA_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MxOhYTsy_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZWaPizK2_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rvhES7tz_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O4p1XfYR_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AyizluX3_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gWZlGE3K_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qm4j1N3n_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DB3NP186_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aI9a7L4D_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_lcfWwY2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rhLTYqr3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_VJGjXq21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bLSoRBnk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qegNp8Za_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dZ3U7rZX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_FPgdi6tA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jaLEJhle_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_MxOhYTsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X8cIpY0J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ZWaPizK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QwlJKlvJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_rvhES7tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VUalZM7d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_O4p1XfYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KYsDtTIU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_AyizluX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_guoSwXtP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_gWZlGE3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aK8l13Fp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qm4j1N3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i7SMCGyD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_DB3NP186_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tTikWIYa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aI9a7L4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KgtvJMux_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fOiKQBmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ki804htm, HV_BINOP_MULTIPLY, 0, m, &cBinop_ki804htm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ki804htm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mV95VbMG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_Lgaq3EZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5UsQDU2l, 0, m, &cVar_5UsQDU2l_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gDxilEMV, 0, m, &cVar_gDxilEMV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bAA6CP3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fOiKQBmP, HV_BINOP_DIVIDE, 1, m, &cBinop_fOiKQBmP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aZdd8Dha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5UsQDU2l, 0, m, &cVar_5UsQDU2l_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dqHKBwVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gDxilEMV, 0, m, &cVar_gDxilEMV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rhLTYqr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bLSoRBnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dZ3U7rZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jaLEJhle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_X8cIpY0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QwlJKlvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VUalZM7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KYsDtTIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_guoSwXtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aK8l13Fp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_i7SMCGyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tTikWIYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KgtvJMux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqHKBwVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZdd8Dha_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_PbMtZuf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHbcIIhL, HV_BINOP_DIVIDE, 0, m, &cBinop_RHbcIIhL_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xgOXansH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PrYXRgTN, HV_BINOP_MULTIPLY, 1, m, &cBinop_PrYXRgTN_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_bxUEZAkF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ekHP5aXT, 0, m, &cSlice_ekHP5aXT_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tY6C54NB, 0, m, &cSlice_tY6C54NB_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wwK80nLO_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qAkIpU3C_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ekHP5aXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_uCU4iqGM, 0, m, &cVar_uCU4iqGM_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_uCU4iqGM, 0, m, &cVar_uCU4iqGM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_tY6C54NB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_LeXjQPKC, HV_BINOP_NEQ, 1, m, &cBinop_LeXjQPKC_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_uCU4iqGM, 1, m, &cVar_uCU4iqGM_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_LeXjQPKC, HV_BINOP_NEQ, 1, m, &cBinop_LeXjQPKC_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_uCU4iqGM, 1, m, &cVar_uCU4iqGM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_uCU4iqGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_sAYFcxXC_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ifMU2Ddl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e7twbH8V_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NgUpWKaN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_NgUpWKaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uCU4iqGM, 0, m, &cVar_uCU4iqGM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_e7twbH8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LeXjQPKC, HV_BINOP_NEQ, 1, m, &cBinop_LeXjQPKC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LeXjQPKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ifMU2Ddl, 1, m, &cIf_ifMU2Ddl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qAkIpU3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ifMU2Ddl, 0, m, &cIf_ifMU2Ddl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wwK80nLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LeXjQPKC, HV_BINOP_NEQ, 0, m, &cBinop_LeXjQPKC_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_CHUeejTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rM46iQti_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vVubM5rr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_WYA3Jb08_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_suR9lZHt_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zznqs7Z6_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n9CaTiVV_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cYZhLUtr_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vC3LSgnx_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NcoP6iA1_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wo6LJ24h_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C399k87U_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sCmKJ92m_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PoNUOnhF_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IlAtRN2v_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wSwlPNqv_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hII8Puz6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_suR9lZHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QnGeMPgf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_zznqs7Z6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wjjnYdJa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_n9CaTiVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S8ajNADI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_cYZhLUtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0KULeWFa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_vC3LSgnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_823XMxwj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_NcoP6iA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IJJtfPcD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Wo6LJ24h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7JPMCAZd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_C399k87U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nH44wxX8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sCmKJ92m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U065d0ed_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PoNUOnhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0GDUxZOp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_IlAtRN2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dVEFdvBi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_wSwlPNqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3YXSRmHg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_hII8Puz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LfzHf4lw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_RHbcIIhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PrYXRgTN, HV_BINOP_MULTIPLY, 0, m, &cBinop_PrYXRgTN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PrYXRgTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bxUEZAkF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_rM46iQti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHbcIIhL, HV_BINOP_DIVIDE, 1, m, &cBinop_RHbcIIhL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vVubM5rr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PbMtZuf5, 0, m, &cVar_PbMtZuf5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xgOXansH, 0, m, &cVar_xgOXansH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xrCeRY5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PbMtZuf5, 0, m, &cVar_PbMtZuf5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wZAUUvi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xgOXansH, 0, m, &cVar_xgOXansH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QnGeMPgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wjjnYdJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_S8ajNADI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0KULeWFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_823XMxwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IJJtfPcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7JPMCAZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nH44wxX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_U065d0ed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0GDUxZOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dVEFdvBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3YXSRmHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LfzHf4lw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZAUUvi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrCeRY5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CeBLiXZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XiPdytgl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_iIr2CS6q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_udohSKpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XiPdytgl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_iIr2CS6q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nfpfRz0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XiPdytgl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_iIr2CS6q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_MlwQmtsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XiPdytgl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_iIr2CS6q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Ggb7jxW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XiPdytgl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_iIr2CS6q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_PcRh2TCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_KQMSurnD, 0, m, &cVar_KQMSurnD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_45JY0M6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_NM6acaFf, 0, m, &cVar_NM6acaFf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2f0nSEdB, 0, m, &cVar_2f0nSEdB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LvVjHrVH, 0, m, &cVar_LvVjHrVH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XE62qjom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_L61SNBtI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_EtA70B7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_L61SNBtI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_2BebgkzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IulijYFc, 0, m, &cVar_IulijYFc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_S4uLJ3Tp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qAVGWcS9, 0, m, &cVar_qAVGWcS9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Sn4zaZ4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RB9gw8rI, 0, m, &cVar_RB9gw8rI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9AJFxr2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_L61SNBtI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_AzSUMlfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_L61SNBtI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_v4PUC1Ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XYrC8jOn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RdJ7ZF4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XYrC8jOn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_UdTArUtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SKw5e4jd, 0, m, &cVar_SKw5e4jd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x5laqXRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8K1lHMHg, 0, m, &cVar_8K1lHMHg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aZYvBNLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y3rqq0F1, 0, m, &cVar_Y3rqq0F1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6FNvRB9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XYrC8jOn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_X9yzTv3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XYrC8jOn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_brk1XdeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_i8m3ivvv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_lv7rt2iR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_i8m3ivvv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_UKijcOn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5wvHkT4E, 0, m, &cVar_5wvHkT4E_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QmlhsO1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gDNdjVse, 0, m, &cVar_gDNdjVse_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BkO2XA4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WrYkEG8W, 0, m, &cVar_WrYkEG8W_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uvNgSNjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_i8m3ivvv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hWehpOU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_i8m3ivvv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_CJy7RW00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FsKHr6XP, 0, m, &cVar_FsKHr6XP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ptl2w7eZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vska3Pie_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SPvOvXLU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iBXbrxpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HpE3tbIv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6PK2Zynp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HpE3tbIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YN12LwFz, 1, m, &cIf_YN12LwFz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6PK2Zynp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r3bNIcAA, 0, m, &cVar_r3bNIcAA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SPvOvXLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FsKHr6XP, 0, m, &cVar_FsKHr6XP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Vska3Pie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IKLX05Wa, 1, m, &cIf_IKLX05Wa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_S1uwJZQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Da9sCEk9, 0, m, &cVar_Da9sCEk9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L0YJfBG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_deef1Km1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZzTbswOY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5hAy6X6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qZQjTHfA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oI9afmM7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qZQjTHfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0Nq3IXtG, 1, m, &cIf_0Nq3IXtG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oI9afmM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7zAC2a44, 0, m, &cVar_7zAC2a44_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_deef1Km1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7Ajh2rFS, 1, m, &cIf_7Ajh2rFS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZzTbswOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Da9sCEk9, 0, m, &cVar_Da9sCEk9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sAYFcxXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y4xo67uc, 0, m, &cVar_y4xo67uc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5sTEor4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9D4L1BBQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zRhYrqvY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1kRXYU3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yuYeyxa7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8rbAkJDM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8rbAkJDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WA0SEQCY, 0, m, &cVar_WA0SEQCY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yuYeyxa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aHVNALKW, 1, m, &cIf_aHVNALKW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9D4L1BBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RYtzLkZK, 1, m, &cIf_RYtzLkZK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zRhYrqvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y4xo67uc, 0, m, &cVar_y4xo67uc_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_iTekpQ5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NM6acaFf, 0, m, &cVar_NM6acaFf_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jzMrWg4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2f0nSEdB, 0, m, &cVar_2f0nSEdB_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_HnauRGlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LvVjHrVH, 0, m, &cVar_LvVjHrVH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_A9xaW2os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BX1c18fq, 0, m, &cVar_BX1c18fq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_dHnXAMaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CthKcHIb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4JyYaUGK_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_l3zhFGK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hKI1omFZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uUTTo7zi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CtSGgSCk_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_WhcyzXNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TduksJh8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wwroz6i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n4jyNJxi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4Z9qqmcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ILj0qXLF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W1aOoOem_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V0fxtWeK_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_9amjkNXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7OegB3yr_sendMessage(_c, 0, m);
  cMsg_jQQxU3bI_sendMessage(_c, 0, m);
  cMsg_oXTES7OJ_sendMessage(_c, 0, m);
  cMsg_qIDjItMZ_sendMessage(_c, 0, m);
  cMsg_RbLDXUXW_sendMessage(_c, 0, m);
  cMsg_uhTjsdIt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YVlpIwUP, 0, m, &cVar_YVlpIwUP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BX1c18fq, 0, m, &cVar_BX1c18fq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DjLqCqSv, 0, m, &cVar_DjLqCqSv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0AjaKOCA, 0, m, &cVar_0AjaKOCA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K8H53V02, 0, m, &cVar_K8H53V02_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zJKK0H0m, 0, m, &cVar_zJKK0H0m_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vRh2iLfO, 0, m, &cVar_vRh2iLfO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_slhxln3W, 0, m, &cVar_slhxln3W_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LDRqaBeT, 0, m, &cVar_LDRqaBeT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tSpa8K8l, 0, m, &cVar_tSpa8K8l_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eUHb5rIu, 0, m, &cVar_eUHb5rIu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0mwQgrcS, 0, m, &cVar_0mwQgrcS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LrfnwP1u, 0, m, &cVar_LrfnwP1u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yLKjRODC, 0, m, &cVar_yLKjRODC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mvNnx7Xc, 0, m, &cVar_mvNnx7Xc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_12UxQ21Y, 0, m, &cVar_12UxQ21Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7E1XdGHn, 0, m, &cVar_7E1XdGHn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cIQFoNpQ, 0, m, &cVar_cIQFoNpQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v9zvijTR, 0, m, &cVar_v9zvijTR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_THS3pkUe, 0, m, &cVar_THS3pkUe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZaHymWZE, 0, m, &cVar_ZaHymWZE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eVnSRCCV, 0, m, &cVar_eVnSRCCV_sendMessage);
  cMsg_1WgzSyZm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SxEoi12Z, 0, m, &cVar_SxEoi12Z_sendMessage);
  cMsg_vRl5spfj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_11KsIFvJ, 0, m, &cVar_11KsIFvJ_sendMessage);
  cMsg_Rs4U4NpL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_H6rbuXRN, 0, m, &cVar_H6rbuXRN_sendMessage);
  cMsg_3jrn0ElH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1Qw0GnSd, 0, m, &cVar_1Qw0GnSd_sendMessage);
  cMsg_lsMkuOJG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3SpvmZij, 0, m, &cVar_3SpvmZij_sendMessage);
  cMsg_05QyZOvS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Tnlhgbz5, 0, m, &cVar_Tnlhgbz5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Z3d5nhTW, 0, m, &cVar_Z3d5nhTW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dRzA5jTe, 0, m, &cVar_dRzA5jTe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_estm9ecK, 0, m, &cVar_estm9ecK_sendMessage);
  cMsg_8gjMl7ZO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZPQnXi2q, 0, m, &cVar_ZPQnXi2q_sendMessage);
  cMsg_BpalQJUy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DvmCnoCL, 0, m, &cVar_DvmCnoCL_sendMessage);
  cMsg_Wm6hakuB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_T9RFLJyq, 0, m, &cVar_T9RFLJyq_sendMessage);
  cMsg_7z8mXT0B_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WOkEE4zE, 0, m, &cVar_WOkEE4zE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QQIHBXKs, 0, m, &cVar_QQIHBXKs_sendMessage);
  cMsg_vpRsQkb6_sendMessage(_c, 0, m);
  cMsg_fUhKKHE6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hK4UzVdW, 0, m, &cVar_hK4UzVdW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iELx3gHM, 0, m, &cVar_iELx3gHM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zIxzuxHs, 0, m, &cVar_zIxzuxHs_sendMessage);
  cMsg_cwq46Lvo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VzagbFsl, 0, m, &cVar_VzagbFsl_sendMessage);
  cMsg_5YrOk96A_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rQr2U2ia, 0, m, &cVar_rQr2U2ia_sendMessage);
  cMsg_RgWmG7M6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RIAQtnQo, 0, m, &cVar_RIAQtnQo_sendMessage);
  cMsg_sGBNXPeT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SxTaV1ZB, 0, m, &cVar_SxTaV1ZB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PJHOhvaL, 0, m, &cVar_PJHOhvaL_sendMessage);
  cMsg_SYiCLT5z_sendMessage(_c, 0, m);
  cMsg_EowopJqS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NEyD8hyQ, 0, m, &cVar_NEyD8hyQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mSPmdp2N, 0, m, &cVar_mSPmdp2N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RhIqKyIb, 0, m, &cVar_RhIqKyIb_sendMessage);
  cMsg_tTserdJf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RHtcTtEW, 0, m, &cVar_RHtcTtEW_sendMessage);
  cMsg_JJgbpN6z_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5ExCfMeW, 0, m, &cVar_5ExCfMeW_sendMessage);
  cMsg_hiphU4VR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nmZyejLc, 0, m, &cVar_nmZyejLc_sendMessage);
  cMsg_stQv3IXr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zRZl5bw5, 0, m, &cVar_zRZl5bw5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GxC6LnUz, 0, m, &cVar_GxC6LnUz_sendMessage);
  cMsg_CU4ivoFE_sendMessage(_c, 0, m);
  cMsg_kOgjoa2D_sendMessage(_c, 0, m);
  cMsg_45JY0M6I_sendMessage(_c, 0, m);
  cMsg_PcRh2TCA_sendMessage(_c, 0, m);
  cMsg_cP7CH3sH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WOcUptEj, 0, m, &cVar_WOcUptEj_sendMessage);
  cMsg_hVMmfBPG_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OILW3jfW, 0, m, &cTabhead_OILW3jfW_sendMessage);
  cMsg_6eWw9er2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3pRlu4QV, 0, m, &cVar_3pRlu4QV_sendMessage);
  cMsg_W5IwNwtd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_4As2gGAg, 0, m, &cTabhead_4As2gGAg_sendMessage);
  cMsg_ThTz0BjD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_9SK4VCUg, 0, m, &cVar_9SK4VCUg_sendMessage);
  cMsg_28p8iRuA_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_CWfluwZY, 0, m, &cTabhead_CWfluwZY_sendMessage);
  cMsg_ltvPfxaY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NN8KfqgD, 0, m, &cVar_NN8KfqgD_sendMessage);
  cMsg_Tk5xSNQp_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_EAFgGpid, 0, m, &cTabhead_EAFgGpid_sendMessage);
  cMsg_0p0k0Pyw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uxtrqjdW, 0, m, &cVar_uxtrqjdW_sendMessage);
  cMsg_2fTog3mb_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_rtNHs1pf, 0, m, &cTabhead_rtNHs1pf_sendMessage);
  cMsg_xhLrhfmo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_9MtLESzg, 0, m, &cVar_9MtLESzg_sendMessage);
  cMsg_lFD1r0pP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_TUqyUSSA, 0, m, &cTabhead_TUqyUSSA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_EU9d5Z35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_raLUnb9g, HV_BINOP_MULTIPLY, 0, m, &cBinop_raLUnb9g_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_lBYAlQ7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LM1jBmC8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Si4Y3OUe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vhdVQIp1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_v5a8eH2a_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_3c6O255l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KrFqtRUw_sendMessage);
  cMsg_9LGUR5pX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_Ip85ejWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z5IWpqhm, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z5IWpqhm_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_rmNEV2TD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_HEtYx2Ov_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qDFQwlf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KstAfwlN, HV_BINOP_MULTIPLY, 1, m, &cBinop_KstAfwlN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ODxdjk8m_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qFIX1Agh_sendMessage);
  cMsg_xjZ4Zu03_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_yFvGxecI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IMV961Iv, HV_BINOP_MULTIPLY, 0, m, &cBinop_IMV961Iv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VSJn6NvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rjiJnnah_sendMessage(_c, 0, m);
  cMsg_wesYtAxd_sendMessage(_c, 0, m);
  cMsg_fJcTlWxx_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Xxw4btRQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_fHW36bUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jxvluvrR_sendMessage);
  cMsg_BR55Gw7t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_t1Hhj4hL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K8H53V02, 0, m, &cVar_K8H53V02_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_OkE06t34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rr6WnidU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_93q3kUdO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_BW3ArWVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WCzMOfXl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ml5kOm6w_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZYOXQ19R_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_sSmzzn8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7WtxtOJL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rMUamBgM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9Xg5FgMg_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AwqfwImJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MST2fGEe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ped9OBud_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mwSJ4mEM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_BMfmRybp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cKOwQ6aT, HV_BINOP_MULTIPLY, 0, m, &cBinop_cKOwQ6aT_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_CnFqJLJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_T0lX6mSD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_uoCi1SFq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fDKO1i3o_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_idOtp5Ol_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_o1tRKvJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LHzxLCjS_sendMessage);
  cMsg_UbqFmKY6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_jwkx6LqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FYBJy8bb, HV_BINOP_MULTIPLY, 0, m, &cBinop_FYBJy8bb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_aRwKSAjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ySiP2Opj_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_q7VjtljZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jw7ZXvnP, HV_BINOP_MULTIPLY, 1, m, &cBinop_Jw7ZXvnP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ykCv7pdb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6fnGT5d0_sendMessage);
  cMsg_X4Dj4JEt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_BO78P08o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xeUL34IS, HV_BINOP_MULTIPLY, 0, m, &cBinop_xeUL34IS_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_NN4sq7aW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2xyZphDT_sendMessage(_c, 0, m);
  cMsg_EiErLO0x_sendMessage(_c, 0, m);
  cMsg_8ehzhpc1_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_5o4zCMAB_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_7wFegc84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mJMA0CYw_sendMessage);
  cMsg_f3QRinX1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_QQJbQcPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KQMSurnD, 0, m, &cVar_KQMSurnD_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Eh3VwBFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_2BebgkzA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_but82jKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_S4uLJ3Tp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_7Zcbdh8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Sn4zaZ4n_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xyMtw8qT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_UdTArUtp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Qw9S0PbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_x5laqXRm_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wiIFFWzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_UKijcOn2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_b1aTLUXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_QmlhsO1o_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nitMiGOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_BkO2XA4D_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_RTNuNln0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_aZYvBNLo_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_6rPRNRhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C0mt2yMt, HV_BINOP_MULTIPLY, 1, m, &cBinop_C0mt2yMt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_30iX2m4T_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vZ3VPjsv, HV_BINOP_MULTIPLY, 1, m, &cBinop_vZ3VPjsv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8WUVTh27_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_R21RMirD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_38XIk66m, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xUgvKULK, m);
}

void Heavy_WSTD_DL3Y::cReceive_FTXCoCZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vwaBGx7q_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_HUpHRyHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_tgsLowuD_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_X0yXp7gF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z0MjBnfJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z0MjBnfJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nQut9rpb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_e5Ry4GUx, HV_BINOP_MULTIPLY, 1, m, &cBinop_e5Ry4GUx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2yJvQhRM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qDFH7X29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4NqJNcVL, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zmPdkgOB, m);
}

void Heavy_WSTD_DL3Y::cReceive_0aI3Hqoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_q4qML1yb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nT7jiRgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_puSTArsM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ba5FQief_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q43KK0WV, HV_BINOP_MULTIPLY, 1, m, &cBinop_q43KK0WV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sPmtJw7N_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bdnvktuQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_bdnvktuQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_62sb3EzL_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_bHfDdR65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4OO5HHqn, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WVjtE2Yy, m);
}

void Heavy_WSTD_DL3Y::cReceive_Ibfo7HYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Shs3PeTh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_oIF66tto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_nncJtpMx_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_cWrUl0l1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r3bNIcAA, 0, m, &cVar_r3bNIcAA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_WG80Py5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fEstoHfQ, 0, m, &cVar_fEstoHfQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_iy8b5M1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T4Glud5H, 0, m, &cVar_T4Glud5H_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_R7ZHqxyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7zAC2a44, 0, m, &cVar_7zAC2a44_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_KLjcMVEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WA0SEQCY, 0, m, &cVar_WA0SEQCY_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_YJQmshYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oevGClSi, 0, m, &cVar_oevGClSi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ZL6Yg586_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yE5SP7md, 0, m, &cVar_yE5SP7md_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LsaReSyE, 0, m, &cVar_LsaReSyE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CHUeejTP, 0, m, &cVar_CHUeejTP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_aKt8vofa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3oHroRfX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_SvCCjORg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gGFqgxaq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_N4rp0U7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WYA3Jb08_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_I6wprYIi, VOf(Bf0));
    __hv_line_f(&sLine_vTfbv1xq, VOf(Bf1));
    __hv_line_f(&sLine_cvU3u3b4, VOf(Bf2));
    __hv_line_f(&sLine_knz5PubY, VOf(Bf3));
    __hv_line_f(&sLine_jFr06Sw1, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_XHsLvNKH, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_VjwpR1c3, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_Qs1dRYiM, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_kDXkBOSj, VOf(Bf1));
    __hv_line_f(&sLine_ilkqabTU, VOf(Bf0));
    __hv_line_f(&sLine_mr2uuxAO, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_IX4R3335, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_W86PE782, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_wK6nvYIF, VOf(Bf5));
    __hv_line_f(&sLine_z0kfwbHu, VOf(Bf1));
    __hv_line_f(&sLine_FL2esOLa, VOf(Bf2));
    __hv_line_f(&sLine_70Lbg4tp, VOf(Bf4));
    __hv_line_f(&sLine_bym6TQ35, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_xGA0I8MV, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_Wn8wvYRI, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_NcFBbVig, VOf(Bf6));
    __hv_line_f(&sLine_XzNvP8n7, VOf(Bf2));
    __hv_line_f(&sLine_ZepcElHM, VOf(Bf1));
    __hv_line_f(&sLine_f0o5g4BF, VOf(Bf5));
    __hv_line_f(&sLine_97GiIisa, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_4EMx2Esp, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_cGjQBxew, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_kCNhuBUy, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_tCDmgDXu, VOf(Bf2));
    __hv_line_f(&sLine_PITmoIZn, VOf(Bf6));
    __hv_line_f(&sLine_WXVJivOp, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_izkiXmgm, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Z4Zl93tK, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_xNt8xlfB, VOf(Bf8));
    __hv_line_f(&sLine_VMq9IJQU, VOf(Bf2));
    __hv_line_f(&sLine_Ce9s4Hqw, VOf(Bf1));
    __hv_line_f(&sLine_VM32LE3s, VOf(Bf7));
    __hv_line_f(&sLine_1dn2ZUdU, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_p7aR0ZxA, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_WYEtuFBT, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_gX3smx94, VOf(Bf9));
    __hv_tabread_f(&sTabread_88P4l8N4, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_EKWHcDK0, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_WUhCUCVK, VOf(Bf9));
    __hv_tabread_f(&sTabread_9fuDOVFz, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_WBSmVDMx, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_SS7bFKBN, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_yrkQtW8f, VOf(Bf3));
    __hv_rpole_f(&sRPole_kgq26g21, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_X2Sw2L0r, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_nCNM4r3j, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_IZSaLWyz, VIf(Bf3));
    __hv_varread_f(&sVarf_oiDIp1dP, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_pjTm3lfw, VOf(Bf5));
    __hv_rpole_f(&sRPole_gjXGKYVF, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_PuDzHXUA, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_p65BqMTm, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_DAZh7ws1, VIf(Bf5));
    __hv_varread_f(&sVarf_38XIk66m, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_EnmN5MUc, VOf(Bf1));
    __hv_varread_f(&sVarf_xUgvKULK, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_0tHkpsEL, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Q490Pevp, VOf(Bf1));
    __hv_varread_f(&sVarf_fe7Aq868, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_HivQpNbB, VOf(Bf1));
    __hv_rpole_f(&sRPole_YqVFHmBt, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_1Xc2WVmh, VIf(Bf8), &sEnv_1Xc2WVmh_sendMessage);
    __hv_varread_f(&sVarf_k1LGLNE6, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Ki4OCpCU, VOf(Bf1));
    __hv_rpole_f(&sRPole_zZbGySmU, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_SS7bFKBN, VIf(Bf1));
    __hv_line_f(&sLine_latT5FNF, VOf(Bf1));
    __hv_line_f(&sLine_g7HO80IZ, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_3cyfyuTo, VOf(Bf1));
    __hv_varread_f(&sVarf_YmmNyNCI, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_9LIrRBnH, VOf(Bf1));
    __hv_rpole_f(&sRPole_dCTlh1WD, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_4Y8LDrh0, VIf(Bf8), &sEnv_4Y8LDrh0_sendMessage);
    __hv_varread_f(&sVarf_3W3OCKMW, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_FYTaIjq2, VOf(Bf1));
    __hv_rpole_f(&sRPole_NfBItrPI, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_oiDIp1dP, VIf(Bf1));
    __hv_varwrite_f(&sVarf_rt1XWyxI, VIf(Bf2));
    __hv_varread_f(&sVarf_LZ5U4gqK, VOf(Bf2));
    __hv_varread_f(&sVarf_jemOpD3E, VOf(Bf1));
    __hv_line_f(&sLine_DBGJo0M6, VOf(Bf8));
    __hv_tabread_f(&sTabread_tEe7T59t, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_qXFagoE8, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_szICNOzI, VOf(Bf8));
    __hv_tabread_f(&sTabread_JBbdrubd, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_yS8mLSqf, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_lf8XHyBb, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_1hgTVPUz, VOf(Bf2));
    __hv_rpole_f(&sRPole_rG9IBoGB, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_MMRDclYn, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_1NBiUugJ, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_YNhQVaMz, VIf(Bf2));
    __hv_varread_f(&sVarf_VmRBCBy3, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_stJtppda, VOf(Bf1));
    __hv_rpole_f(&sRPole_spxhUw54, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_8c53qvK0, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Fl03eEjh, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_U0lQgC0L, VIf(Bf1));
    __hv_varread_f(&sVarf_4NqJNcVL, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_RTCmVshi, VOf(Bf3));
    __hv_varread_f(&sVarf_zmPdkgOB, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_7YEMQ66A, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_CBudM7Zj, VOf(Bf3));
    __hv_varread_f(&sVarf_kJes2FXU, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_7QwyWToa, VOf(Bf3));
    __hv_rpole_f(&sRPole_MR9TixRZ, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_FmRRQinS, VIf(Bf9), &sEnv_FmRRQinS_sendMessage);
    __hv_varread_f(&sVarf_AooqllU8, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_0WVJXuXU, VOf(Bf3));
    __hv_rpole_f(&sRPole_Zh59bdsm, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_lf8XHyBb, VIf(Bf3));
    __hv_line_f(&sLine_IlN73JKL, VOf(Bf3));
    __hv_line_f(&sLine_CHRiuvds, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_mtXgrCU9, VOf(Bf3));
    __hv_varread_f(&sVarf_AQPWyglo, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_MC4i5IEe, VOf(Bf3));
    __hv_rpole_f(&sRPole_rP88tipV, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_VMyB4ERs, VIf(Bf9), &sEnv_VMyB4ERs_sendMessage);
    __hv_varread_f(&sVarf_WkugDomD, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_w6VxHtNH, VOf(Bf3));
    __hv_rpole_f(&sRPole_SHyL1paq, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_VmRBCBy3, VIf(Bf3));
    __hv_varwrite_f(&sVarf_o7PH2VIN, VIf(Bf5));
    __hv_varread_f(&sVarf_bxX0nwSp, VOf(Bf5));
    __hv_varread_f(&sVarf_YQQycb0E, VOf(Bf3));
    __hv_line_f(&sLine_HJqrgxnp, VOf(Bf9));
    __hv_tabread_f(&sTabread_EQCjqBiZ, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_VakqqU9H, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_svvfxEeX, VOf(Bf9));
    __hv_tabread_f(&sTabread_Ghk2qPiE, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_OHFFT9xn, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_gdWvqXbP, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_GRHbp2Gr, VOf(Bf5));
    __hv_rpole_f(&sRPole_Neh5Qp7D, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_lYbUgBbd, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_qiCoBg3U, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_d5YAn1r5, VIf(Bf5));
    __hv_varread_f(&sVarf_JNMVufC4, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_h9QdCowF, VOf(Bf3));
    __hv_rpole_f(&sRPole_rY6vTiS5, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_p5czLoNC, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_mPM7CMKo, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_InYlpA9W, VIf(Bf3));
    __hv_varread_f(&sVarf_4OO5HHqn, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_QDv9EnMu, VOf(Bf2));
    __hv_varread_f(&sVarf_WVjtE2Yy, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_7hOZIiUh, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_8rmWgXZf, VOf(Bf2));
    __hv_varread_f(&sVarf_2RLt09RX, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Cyp4TkbL, VOf(Bf2));
    __hv_rpole_f(&sRPole_PK2pWXDD, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_cdB17ugT, VIf(Bf8), &sEnv_cdB17ugT_sendMessage);
    __hv_varread_f(&sVarf_fkS7dNPe, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_J6FEfXyu, VOf(Bf2));
    __hv_rpole_f(&sRPole_spYDqcfF, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_gdWvqXbP, VIf(Bf2));
    __hv_line_f(&sLine_DQcT6Jcw, VOf(Bf2));
    __hv_line_f(&sLine_rVxW7bIZ, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_cHxVmFla, VOf(Bf2));
    __hv_varread_f(&sVarf_LeXb1Czs, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_Kas2Ya6A, VOf(Bf2));
    __hv_rpole_f(&sRPole_Gm1ycBpY, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_GweqS9hl, VIf(Bf8), &sEnv_GweqS9hl_sendMessage);
    __hv_varread_f(&sVarf_l6KOArSv, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_K1RdOUoV, VOf(Bf2));
    __hv_rpole_f(&sRPole_tdCrF4Zt, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_JNMVufC4, VIf(Bf2));
    __hv_varwrite_f(&sVarf_25Hbiy0A, VIf(Bf1));
    __hv_varwrite_f(&sVarf_gYN3tyfm, VIf(Bf10));
    __hv_varwrite_f(&sVarf_oGTRQl4N, VIf(Bf11));
    __hv_varwrite_f(&sVarf_Wioaxwub, VIf(Bf12));
    __hv_varwrite_f(&sVarf_LZ5U4gqK, VIf(Bf0));
    __hv_varwrite_f(&sVarf_jemOpD3E, VIf(Bf6));
    __hv_varwrite_f(&sVarf_bxX0nwSp, VIf(Bf4));
    __hv_varwrite_f(&sVarf_YQQycb0E, VIf(Bf7));
    __hv_varread_f(&sVarf_gYN3tyfm, VOf(Bf7));
    __hv_varread_f(&sVarf_oGTRQl4N, VOf(Bf4));
    __hv_varread_f(&sVarf_Wioaxwub, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_rt1XWyxI, VOf(Bf6));
    __hv_varread_f(&sVarf_o7PH2VIN, VOf(Bf7));
    __hv_varread_f(&sVarf_25Hbiy0A, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
